<?php

namespace WPGPL\Child\Api;

if (!defined('ABSPATH')) {
    exit;
}

use WPGPL\Child\Utils\IpUtils;
use WP_REST_Request;

class DeleteIpApi {
    
    public static function register_routes() {
        register_rest_route('wpgpl-child/v1', '/delete/', [
            'methods'  => 'DELETE',
            'callback' => [self::class, 'delete_authorized_ip'],
            'permission_callback' => '__return_true',
        ]);
    }

    public static function delete_authorized_ip(WP_REST_Request $request) {
        // Obter o IP do usuário que fez a requisição
        $user_ip = IpUtils::get_user_ip();

        // Verificar se o option 'wpgpl_child_authorized_ip' já está definido
        $authorized_ip = get_option('wpgpl_child_authorized_ip', '');

        // Se o option estiver vazio, retornar erro
        if (empty($authorized_ip)) {
            return new \WP_Error('no_authorized_ip', 'Nenhum IP autorizado encontrado.', array('status' => 403));
        }

        // Se o IP não corresponder ao armazenado, retornar erro
        if ($user_ip !== $authorized_ip) {
            return new \WP_Error('unauthorized', 'Acesso negado. IP não autorizado.', array('status' => 403));
        }

        // Deletar o IP autorizado
        $ip_deleted = delete_option('wpgpl_child_authorized_ip');
        
        // Deletar o domínio principal autorizado
        $domain_deleted = delete_option('wpgpl_child_main_domain');

        if ($ip_deleted && $domain_deleted) {
            return array(
                'success' => true,
                'message' => 'IP autorizado e Domínio principal deletados com sucesso.'
            );
        } else {
            return new \WP_Error('delete_failed', 'Falha ao deletar o IP autorizado ou domínio.', array('status' => 500));
        }
    }
}
