<?php

namespace WPGPL\Child\Api;

if (!defined('ABSPATH')) {
    exit;
}

use WPGPL\Child\Handlers\PluginHandler;
use WPGPL\Child\Handlers\ThemeHandler;
use WP_REST_Request;

class InstallApi {
    public static function register_routes() {
        register_rest_route('wpgpl-child/v1', '/install/', [
            'methods'  => 'POST',
            'callback' => [self::class, 'install'],
            'permission_callback' => '__return_true',
            'args'     => [
                'url'  => [
                    'required' => true,
                    'validate_callback' => function($param) {
                        return filter_var($param, FILTER_VALIDATE_URL);
                    }
                ],
                'type' => [
                    'required' => true,
                    'validate_callback' => function($param) {
                        return in_array($param, ['plugin', 'theme']);
                    }
                ],
            ]
        ]);
    }

    public static function install(WP_REST_Request $request) {
        $url  = $request->get_param('url');
        $type = $request->get_param('type');

        if ($type === 'plugin') {
            return PluginHandler::install_plugin($url);
        } elseif ($type === 'theme') {
            return ThemeHandler::install_theme($url);
        }

        return new \WP_Error('invalid_type', 'Tipo inválido fornecido. Use "plugin" ou "theme".', array('status' => 400));
    }
}
