<?php

namespace WPGPL\Child\Api;

if (!defined('ABSPATH')) {
    exit;
}

use WPGPL\Child\Utils\IpUtils;
use WPGPL\Child\Utils\BackupUtils;
use WP_REST_Request;

class SiteInfoApi {
    
    public static function register_routes() {
        register_rest_route('wpgpl-child/v1', '/site-info/', [
            'methods'  => 'GET',
            'callback' => [self::class, 'get_site_info'],
            'permission_callback' => '__return_true',
            'args'     => [
                'main-domain' => [
                    'required' => true,
                    'validate_callback' => function($param) {
                        return filter_var($param, FILTER_VALIDATE_DOMAIN, FILTER_FLAG_HOSTNAME);
                    }
                ]
            ]
        ]);
    }

    public static function get_site_info(WP_REST_Request $request) {
        $user_ip = IpUtils::get_user_ip();
        $domain = $request->get_param('main-domain');

        // Verificar se o IP autorizado está definido
        $authorized_ip = get_option('wpgpl_child_authorized_ip', '');

        if (empty($authorized_ip)) {
            update_option('wpgpl_child_authorized_ip', $user_ip);
        } elseif ($user_ip !== $authorized_ip) {
            return new \WP_Error('unauthorized', 'Acesso negado. IP não autorizado.', array('status' => 403));
        }

        update_option('wpgpl_child_main_domain', $domain);

        // Coleta as informações gerais do site
        $site_info = array(
            'name'          => get_bloginfo('name'),
            'description'   => get_bloginfo('description'),
            'url'           => home_url(),
            'wp_version'    => get_bloginfo('version'),
            'theme'         => wp_get_theme()->get('Name'),
            'theme_version' => wp_get_theme()->get('Version'),
            'backup_active' => BackupUtils::is_backup_installed(),
            'auto_update_plugins' => false,
            'auto_update_themes'  => false,
        );

        // Plugins instalados
        include_once(ABSPATH . 'wp-admin/includes/plugin.php');
        $all_plugins = get_plugins();
        $plugins = array();
        foreach ($all_plugins as $plugin_file => $plugin_data) {
            $plugins[] = array(
                'name'        => $plugin_data['Name'],
                'version'     => $plugin_data['Version'],
                'active'      => is_plugin_active($plugin_file),
                'auto_update' => false,
                'archived'    => false,
            );
        }

        // Temas instalados
        $all_themes = wp_get_themes();
        $themes = array();
        foreach ($all_themes as $theme_slug => $theme_obj) {
            $themes[] = array(
                'name'        => $theme_obj->get('Name'),
                'version'     => $theme_obj->get('Version'),
                'active'      => $theme_obj->get_stylesheet() === wp_get_theme()->get_stylesheet(),
                'auto_update' => false,
                'archived'    => false,
            );
        }

        return array(
            'site_info' => $site_info,
            'plugins'   => $plugins,
            'themes'    => $themes,
        );
    }
}
