<?php

namespace WPGPL\Child\Events;

if (!defined('ABSPATH')) {
    exit;
}

class BackupHooks {

    // Propriedade para armazenar o domínio sem o protocolo
    private $domain;

    // Construtor da classe para adicionar os hooks e configurar o domínio
    public function __construct() {
        // Define o domínio usando a função parse_url para remover o protocolo
        $this->domain = parse_url(home_url(), PHP_URL_HOST);
        
        add_action('duplicator_pro_build_completed', [$this, 'trigger_update_after_backup']);
        add_action('ai1wm_status_export_done', [$this, 'trigger_update_after_backup']);
        add_action('updraft_final_backup_history', [$this, 'trigger_update_after_backup']);
    }

    /**
     * Callback para os hooks de backup para enviar uma requisição de atualização
     *
     * @param mixed $backup_data Os dados passados pelos hooks, se houver.
     */
    public function trigger_update_after_backup($backup_data) {
        error_log('BackupHooks: Backup concluído, acionando atualização para o domínio ' . $this->domain);

        // Obtém o domínio principal do banco de dados
        $main_domain = get_option('wpgpl_child_main_domain');

        // Verifica se o domínio principal está definido
        if (empty($main_domain)) {
            error_log('Erro: wpgpl_child_main_domain não está definido no banco de dados. Não é possível enviar atualização.');
            return;
        }

        error_log('BackupHooks: Domínio principal recuperado: ' . $main_domain);

        // Construção da URL com o domínio principal e o parâmetro 'site'
        $api_url = "https://$main_domain/wp-json/wpgpl-child/v1/schedule-update?site=" . urlencode($this->domain);
        error_log('BackupHooks: URL da API construída: ' . $api_url);

        // Argumentos para a requisição wp_remote_post
        $args = array(
            'method' => 'POST',
            'timeout' => 45,
            'headers' => array(
                'Content-Type' => 'application/json'
            )
        );

        error_log('BackupHooks: Enviando requisição wp_remote_post para ' . $api_url);

        // Envia a requisição para o endpoint REST
        $response = wp_remote_post($api_url, $args);

        // Verifica se houve algum erro na requisição
        if (is_wp_error($response)) {
            error_log('Erro ao enviar wp_remote_post: ' . $response->get_error_message() . '. Detalhes: ' . print_r($response->get_error_data(), true));
        } else {
            $status_code = wp_remote_retrieve_response_code($response);
            $response_body = wp_remote_retrieve_body($response);
            
            if ($status_code !== 200) {
                error_log('BackupHooks: Requisição falhou. Código de resposta: ' . $status_code . '. Corpo da resposta: ' . $response_body);
            } else {
                error_log('BackupHooks: Requisição enviada com sucesso. Código de resposta: ' . $status_code . '. Corpo da resposta: ' . $response_body);
            }
        }
    }

    /**
     * Método estático para inicializar a classe, pode ser chamado externamente.
     */
    public static function init() {
        new self();
    }
}