<?php

namespace WPGPL\Child\Handlers;

if (!defined('ABSPATH')) {
    exit;
}

use WPGPL\Child\Utils\FileSystemUtils;
use WPGPL\Child\Utils\WPGPL_Upgrader_Skin;

class PluginHandler {

    public static function install_plugin($url) {
        error_log('Iniciando instalação do plugin. URL: ' . $url);

        // Remove ações que podem disparar atualizações automáticas e traduções
        self::disable_updates();

        // Verifica se o sistema de arquivos está acessível
        $filesystem_ready = FileSystemUtils::init_filesystem();
        if (is_wp_error($filesystem_ready)) {
            error_log('Erro ao inicializar o sistema de arquivos: ' . $filesystem_ready->get_error_message());

            // Reativar as ações de atualização
            self::enable_updates();
            return $filesystem_ready;
        }

        // Carrega as classes necessárias para atualizar o plugin
        require_once(ABSPATH . 'wp-admin/includes/class-wp-upgrader.php');

        // Usa a classe personalizada de skin para evitar mensagens na instalação
        $skin = new WPGPL_Upgrader_Skin();
        $upgrader = new \Plugin_Upgrader($skin);

        // Executa a instalação ou atualização do plugin
        $result = $upgrader->run(array(
            'package'           => $url,                      // URL do plugin a ser instalado
            'destination'       => WP_PLUGIN_DIR,             // Diretório de destino do plugin
            'clear_destination' => true,                      // Sobrescreve o plugin existente, se houver
            'clear_working'     => true,                      // Remove os arquivos temporários
            'hook_extra'        => array('type' => 'plugin', 'action' => 'install') // Extras do hook
        ));

        // Reativar as ações de atualização após a instalação
        self::enable_updates();

        // Verifica se houve erro durante a instalação ou atualização
        if (is_wp_error($result)) {
            error_log('Erro ao instalar o plugin: ' . $result->get_error_message());
            return $result;
        }

        // Log após sucesso na instalação
        error_log('Plugin instalado com sucesso. URL: ' . $url);

        return true;
    }

    // Função para desativar temporariamente todas as atualizações automáticas
    private static function disable_updates() {
        // Remove atualizações automáticas de plugins
        remove_action('init', 'wp_maybe_auto_update');
        remove_action('admin_init', 'wp_maybe_auto_update');
        remove_action('wp_loaded', 'wp_maybe_auto_update');

        // Remove atualização de traduções
        remove_action('init', 'wp_maybe_auto_update_translations');
        remove_action('admin_init', 'wp_maybe_auto_update_translations');
        remove_action('wp_loaded', 'wp_maybe_auto_update_translations');
    }

    // Função para reativar as atualizações automáticas após o processo de instalação
    private static function enable_updates() {
        // Reativa atualizações automáticas de plugins
        add_action('init', 'wp_maybe_auto_update');
        add_action('admin_init', 'wp_maybe_auto_update');
        add_action('wp_loaded', 'wp_maybe_auto_update');

        // Reativa atualização de traduções
        add_action('init', 'wp_maybe_auto_update_translations');
        add_action('admin_init', 'wp_maybe_auto_update_translations');
        add_action('wp_loaded', 'wp_maybe_auto_update_translations');
    }
}