<?php

namespace WPGPL\Child\Utils;

if (!defined('ABSPATH')) {
    exit;
}

class DisconnectHandler {

    public static function disconnect() {
        // Lógica de desconexão, por exemplo, remover conexões remotas
        $main_domain = get_option('wpgpl_child_main_domain');
        $home_domain = parse_url(home_url(), PHP_URL_HOST);

        if (empty($main_domain)) {
            error_log('Erro: Nenhum domínio principal encontrado.');
            return new \WP_Error('no_main_domain', 'Nenhum domínio principal encontrado.', array('status' => 404));
        }

        $api_url = "https://$main_domain/wp-json/wpgpl-vault/v1/delete-domain/?domain=" . urlencode($home_domain);
        error_log('Tentando se conectar à URL da API: ' . $api_url);

        $response = wp_remote_request($api_url, array(
            'method' => 'DELETE',
            'headers' => array(
                'Content-Type' => 'application/json'
            ),
            'timeout' => 30,
        ));

        if (is_wp_error($response)) {
            $error_message = $response->get_error_message();
            error_log('Erro ao fazer a requisição DELETE: ' . $error_message);
            return $response;
        }

        $status_code = wp_remote_retrieve_response_code($response);
        if ($status_code !== 200) {
            error_log('Erro de conexão com a API. Código de status: ' . $status_code);
            return new \WP_Error('api_error', 'Erro ao se conectar à API.', array('status' => $status_code));
        }

        error_log('Conexão com a API bem-sucedida.');
        return true;
    }
}
