<?php

namespace WPGPL\Child\Utils;

if (!defined('ABSPATH')) {
    exit;
}

class IpUtils {
    
    /**
     * Obtém o endereço IP do usuário que fez a requisição
     *
     * @return string O endereço IP do usuário ou 'UNKNOWN' se não for possível determinar o IP
     */
    public static function get_user_ip() {
        $ipaddress = '';

        if (!empty($_SERVER['HTTP_CLIENT_IP'])) {
            $ipaddress = $_SERVER['HTTP_CLIENT_IP'];
        } elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
            $ip_list = explode(',', $_SERVER['HTTP_X_FORWARDED_FOR']);
            $ipaddress = trim($ip_list[0]);
        } elseif (!empty($_SERVER['HTTP_X_FORWARDED'])) {
            $ipaddress = $_SERVER['HTTP_X_FORWARDED'];
        } elseif (!empty($_SERVER['HTTP_FORWARDED_FOR'])) {
            $ipaddress = $_SERVER['HTTP_FORWARDED_FOR'];
        } elseif (!empty($_SERVER['HTTP_FORWARDED'])) {
            $ipaddress = $_SERVER['HTTP_FORWARDED'];
        } elseif (!empty($_SERVER['REMOTE_ADDR'])) {
            $ipaddress = $_SERVER['REMOTE_ADDR'];
        } else {
            $ipaddress = 'UNKNOWN';
        }

        // Verifica se o endereço IP é válido (IPv4 ou IPv6)
        if (filter_var($ipaddress, FILTER_VALIDATE_IP, FILTER_FLAG_IPV4) || filter_var($ipaddress, FILTER_VALIDATE_IP, FILTER_FLAG_IPV6)) {
            return $ipaddress;
        } else {
            return 'UNKNOWN';
        }
    }
}
