jQuery(document).ready(function($) {
    $('#delete-ip-btn').on('click', function() {
        // Confirmação antes de enviar a requisição
        if (!confirm('Você tem certeza que deseja desconectar este site?')) {
            return;
        }

        // Obtém o valor do domínio diretamente do atributo data-domain
        var currentSiteUrl = $(this).data('domain');
        var ajaxUrl = '/wp-admin/admin-ajax.php'; // URL padrão do WordPress para AJAX

        // Enviar a requisição AJAX para o WordPress
        $.ajax({
            url: ajaxUrl,
            method: 'POST',
            data: {
                action: 'delete_authorized_ip', // Nome da ação AJAX
                current_site_url: currentSiteUrl // Enviando o URL do site atual
            },
            success: function(response) {
                if (response.success) {
                    window.history.back();
                } else {
                    alert('Erro: ' + response.data.message);
                    console.log(response);
                }
            },
            error: function(response) {
                alert('Erro ao desconectar o domínio. Verifique os logs.');
                console.log(response);
            }
        });
    });

    function revertCheckbox(checkbox, shouldBeChecked) {
        checkbox.prop("checked", shouldBeChecked);
        checkbox.next(".slider").toggleClass("ajax-success", shouldBeChecked);
    }

    // Função para alternar a atualização automática de plugins ou temas
    function toggleAutoUpdate(checkbox, action, entity, enabled, domain) {
        checkbox.prop("disabled", true);
        
        // Armazenar o estado anterior para uso posterior
        var previousChecked = checkbox.is(":checked");

        // Alternar estado visual temporariamente
        revertCheckbox(checkbox, !previousChecked); 

        var data = {
            action: action,
            security: $("#wpgpl_vault_nonce_field").val(),
            enabled: enabled,
            domain: domain // Adiciona o domínio à requisição
        };

        if (entity === "plugin_cron") {
            data["plugin_cron_enabled"] = enabled;
        } else if (entity === "theme_cron") {
            data["theme_cron_enabled"] = enabled;
        } else if (entity === "backup_active") {
            data["backup_active"] = enabled;
        } else {
            data[entity] = checkbox.data(entity);
        }

        $.ajax({
            url: ajaxurl,
            type: "POST",
            data: data,
            success: function(response) {
                if (response.success) {
                    console.log(`Settings saved for ${entity} on ${domain}:`, checkbox.data(entity) || "");
                    revertCheckbox(checkbox, enabled); // Aplicar o estado final após sucesso
                } else {
                    console.log(`Failed to save settings for ${entity} on ${domain}:`, checkbox.data(entity) || "");
                    revertCheckbox(checkbox, previousChecked); // Reverter ao estado anterior se falhou
                }
                checkbox.prop("disabled", false);
                checkbox.next(".slider").toggleClass("ajax-success", checkbox.is(":checked")); // Atualizar a cor do slider
                checkbox.trigger("toggleComplete"); // Dispara um evento para indicar a conclusão do AJAX
            },
            error: function() {
                console.log(`Error in AJAX request for ${entity} on ${domain}:`, checkbox.data(entity) || "");
                revertCheckbox(checkbox, previousChecked); // Reverter ao estado anterior em caso de erro
                checkbox.prop("disabled", false);
                checkbox.next(".slider").toggleClass("ajax-success", checkbox.is(":checked")); // Atualizar a cor do slider
                checkbox.trigger("toggleComplete"); // Dispara um evento para indicar a conclusão do AJAX
            }
        });
    }

    // Processar atualização automática em sequência para ações em massa
    function toggleAutoUpdateInSequence(items, action, enabled, domain, callback) {
        if (items.length === 0) {
            if (callback) callback();
            return;
        }

        var currentItem = items.shift();
        var checkbox = currentItem;

        toggleAutoUpdate(checkbox, action, checkbox.data('type'), enabled, domain);

        // Aguarda a finalização da ativação/desativação atual antes de iniciar a próxima
        checkbox.one("toggleComplete", function() {
            toggleAutoUpdateInSequence(items, action, enabled, domain, callback); // Chama recursivamente até terminar todos os itens
        });
    }

    // Manipuladores de evento para capturar o domínio e fazer a requisição AJAX
    $("#plugin_cron_enabled").on("change", function() {
        var checkbox = $(this);
        var domain = $('#delete-ip-btn').data('domain'); // Captura o domínio
        toggleAutoUpdate(checkbox, "save_wpgpl_child_plugin_cron", "plugin_cron", checkbox.is(":checked") ? 1 : 0, domain);
    });

    $("#theme_cron_enabled").on("change", function() {
        var checkbox = $(this);
        var domain = $('#delete-ip-btn').data('domain'); // Captura o domínio
        toggleAutoUpdate(checkbox, "save_wpgpl_child_theme_cron", "theme_cron", checkbox.is(":checked") ? 1 : 0, domain);
    });

    $(document).on("change", ".auto-update-plugin", function() {
        var checkbox = $(this);
        var domain = $('#delete-ip-btn').data('domain'); // Captura o domínio
        toggleAutoUpdate(checkbox, "save_wpgpl_child_auto_update_plugin", "plugin", checkbox.is(":checked") ? 1 : 0, domain);
    });

    $(document).on("change", ".auto-update-theme", function() {
        var checkbox = $(this);
        var domain = $('#delete-ip-btn').data('domain'); // Captura o domínio
        toggleAutoUpdate(checkbox, "save_wpgpl_child_auto_update_theme", "theme", checkbox.is(":checked") ? 1 : 0, domain);
    });

    $(document).on("change", ".backup_enabled", function() {
        var checkbox = $(this);
        var domain = $('#delete-ip-btn').data('domain'); // Captura o domínio
        toggleAutoUpdate(checkbox, "save_wpgpl_child_backup_active", "backup_enabled", checkbox.is(":checked") ? 1 : 0, domain);
    });

    function initializeCheckboxState() {
        if ($("#plugin_cron_enabled").data("enabled") == 1) {
            $("#plugin_cron_enabled").prop("checked", true).next(".slider").addClass("ajax-success");
        }
        if ($("#theme_cron_enabled").data("enabled") == 1) {
            $("#theme_cron_enabled").prop("checked", true).next(".slider").addClass("ajax-success");
        }
        if ($("#backup_enabled").data("enabled") == 1) {
            $("#backup_enabled").prop("checked", true).next(".slider").addClass("ajax-success");
        }

        $(".auto-update-plugin, .auto-update-theme").each(function() {
            if ($(this).is(":checked")) {
                $(this).next(".slider").addClass("ajax-success");
            }
        });
    }

    initializeCheckboxState();

    // Função para verificar um item por vez no bulk action
    function verifyItemInSequence(items, callback) {
        if (items.length === 0) {
            if (callback) callback();
            return;
        }

        var currentItem = items.shift();
        var button = currentItem.closest("tr").find(".wpgpl-vault-check");

        button.trigger("click"); // Dispara o evento de clique no botão de verificação

        // Aguarda a finalização da verificação atual antes de iniciar a próxima
        button.one("ajaxComplete", function() {
            verifyItemInSequence(items, callback); // Chama recursivamente até terminar todos os itens
        });
    }

    // Selecione/Deselecione todos os plugins e desmarque temas
    $('#select-all-plugins').on('click', function() {
        var checked = $(this).is(':checked');
        $('.plugin-select').each(function() {
            $(this).prop('checked', checked);
        });
        // Desmarcar temas e o checkbox "select all themes"
        $('#select-all-themes').prop('checked', false);
        $('.theme-select').prop('checked', false);
    });

    // Selecione/Deselecione todos os temas e desmarque plugins
    $('#select-all-themes').on('click', function() {
        var checked = $(this).is(':checked');
        $('.theme-select').each(function() {
            $(this).prop('checked', checked);
        });
        // Desmarcar plugins e o checkbox "select all plugins"
        $('#select-all-plugins').prop('checked', false);
        $('.plugin-select').prop('checked', false);
    });

    // Desmarcar plugins quando um tema é selecionado
    $('.theme-select').on('change', function() {
        if ($(this).is(':checked')) {
            $('#select-all-plugins').prop('checked', false);
            $('.plugin-select').prop('checked', false);
        }
    });

    // Desmarcar temas quando um plugin é selecionado
    $('.plugin-select').on('change', function() {
        if ($(this).is(':checked')) {
            $('#select-all-themes').prop('checked', false);
            $('.theme-select').prop('checked', false);
        }
    });

    // Bulk actions para plugins e temas
    $('#doaction').on('click', function() {
        var action = $('#bulk-action-selector-top').val(); // Obtém a ação selecionada no dropdown
        var selectedPlugins = [];
        var selectedThemes = [];
        var domain = $('#delete-ip-btn').data('domain');

        // Coleta plugins selecionados
        $('.plugin-select:checked').each(function() {
            selectedPlugins.push($(this).closest('tr').find('.auto-update-plugin'));
        });

        // Coleta temas selecionados
        $('.theme-select:checked').each(function() {
            selectedThemes.push($(this).closest('tr').find('.auto-update-theme'));
        });

        if (action === '-1') {
            alert('Por favor, selecione uma ação em massa.');
            return;
        }

        if (selectedPlugins.length === 0 && selectedThemes.length === 0) {
            alert('Por favor, selecione pelo menos um plugin ou tema.');
            return;
        }

        switch (action) {
            case 'activate-auto-update':
                toggleAutoUpdateInSequence(selectedPlugins, 'save_wpgpl_child_auto_update_plugin', 1, domain);
                toggleAutoUpdateInSequence(selectedThemes, 'save_wpgpl_child_auto_update_theme', 1, domain);
                break;
            case 'disable-auto-update':
                toggleAutoUpdateInSequence(selectedPlugins, 'save_wpgpl_child_auto_update_plugin', 0, domain);
                toggleAutoUpdateInSequence(selectedThemes, 'save_wpgpl_child_auto_update_theme', 0, domain);
                break;
            case 'verify-update':
                var allItems = selectedPlugins.concat(selectedThemes);
                verifyItemInSequence(allItems);
                break;
            default:
                alert('Ação inválida.');
        }
    });

    // Verificar API ao clicar no botão de verificação
    $(".wpgpl-vault-check").on("click", function() {
        var button = $(this);
        var name = button.data("real-name");
        var typeItem = button.data("type");
        var row = button.closest("tr");
        var currentVersion = row.find(".wpgpl-vault-current-version .version-text").text();
        var resultVersion = row.find(".wpgpl-vault-api-version");
        var resultDownload = row.find(".wpgpl-vault-api-download");
        var resultStatus = row.find(".wpgpl-vault-status");
        var resultVirusTotal = row.find(".wpgpl-vault-virus-total");
        var resultOldDownload = row.find(".wpgpl-vault-api-old-download");
        button.text("Verificando...").prop("disabled", true);

        $.ajax({
            url: ajaxurl,
            type: "GET",
            data: {
                action: "wpgpl_vault_check_api",
                name: name
            },
            success: function(response) {
                if (response.success && response.data.length > 0) {
                    var data = response.data[0];
                    var apiVersion = data.version;
                    var oldVersions = data.old_versions;
                    var virusReport = data.virus_total_report;

                    resultVersion.text(apiVersion).wrapInner("<span></span>").find("span").css({
                        "background-color": "#23c55e",
                        color: "#fff",
                        "font-weight": "600",
                        padding: "4px 6px",
                        "border-radius": "4px"
                    });

                    if (versionCompare(currentVersion, apiVersion) < 0) {
                        resultStatus.text("Desatualizado").wrapInner("<span></span>").find("span").css({
                            "background-color": "#e30047",
                            color: "#fff",
                            "font-weight": "600",
                            padding: "4px 6px",
                            "border-radius": "4px"
                        });
                        resultDownload.html('<button class="wpgpl-vault-download button" data-type="' + typeItem + '" data-real-name="' + name + '"><i class="fas fa-download"></i> Download e Instalar</button>');
                    } else if (versionCompare(currentVersion, apiVersion) > 0) {
                        resultStatus.text("Obsoleta").wrapInner("<span></span>").find("span").css({
                            "background-color": "#ffa500",
                            color: "#fff",
                            "font-weight": "600",
                            padding: "4px 6px",
                            "border-radius": "4px"
                        });
                        resultVersion.text(apiVersion).wrapInner("<span></span>").find("span").css({
                            "background-color": "#ffa500", // Define o fundo laranja para resultVersion
                            color: "#fff",
                            "font-weight": "600",
                            padding: "4px 6px",
                            "border-radius": "4px"
                        });
                        resultDownload.html(""); // Caso não haja ações para versões obsoletas
                    } else {
                        resultStatus.text("Atualizado").wrapInner("<span></span>").find("span").css({
                            "background-color": "#23c55e",
                            color: "#fff",
                            "font-weight": "600",
                            padding: "4px 6px",
                            "border-radius": "4px"
                        });
                        resultDownload.html("");
                    }

                    if (virusReport) {
                        resultVirusTotal.html('<button class="button virus-total-report-button" onclick="window.open(\'' + virusReport + "', '_blank')\"><i class=\"fas fa-file-alt\"></i> Ver Relatório</button>");
                    } else {
                        resultVirusTotal.html("Relatório não disponível");
                    }

                    if (oldVersions && oldVersions.length > 0) {
                        oldVersions.sort(function(a, b) {
                            return b.old_version.localeCompare(a.old_version, undefined, { numeric: true, sensitivity: 'base' });
                        });
                        var dropdownHtml = '<select class="wpgpl-vault-old-version-dropdown">';
                        oldVersions.forEach(function(version) {
                            dropdownHtml += '<option value="' + version.old_version + '">' + version.old_version + '</option>';
                        });
                        dropdownHtml += '</select>';
                        dropdownHtml += '<button class="wpgpl-vault-install-old-version button"><i class="fas fa-download"></i> Instalar Versão ' + oldVersions[0].old_version + '</button>';
                        resultOldDownload.html(dropdownHtml);

                        resultOldDownload.find(".wpgpl-vault-old-version-dropdown").on("change", function() {
                            var selectedVersion = $(this).val();
                            resultOldDownload.find(".wpgpl-vault-install-old-version").html('<i class="fas fa-download"></i> Instalar Versão ' + selectedVersion);
                        });
                    } else {
                        resultOldDownload.html("Não disponível");
                    }
                } else {
                    resultVersion.text("Não encontrado").wrapInner("<span></span>").find("span").css({
                        "background-color": "#e30047",
                        color: "#fff",
                        "font-weight": "600",
                        padding: "4px 6px",
                        "border-radius": "4px"
                    });
                    resultDownload.text("");
                    resultStatus.text("");
                }
                button.html('<i class="fas fa-check-circle"></i> Verificado').prop("disabled", false);
                button.trigger("ajaxComplete"); // Dispara um evento para indicar a conclusão do AJAX
            },
            error: function() {
                resultVersion.text("Erro na requisição");
                resultDownload.text("");
                resultStatus.text("");
                button.text("Verificado").prop("disabled", false);
                button.trigger("ajaxComplete"); // Dispara um evento para indicar a conclusão do AJAX
            },
        });
    });

    // Função de download e instalação
    $(document).on("click", ".wpgpl-vault-download", function() {
        var button = $(this);
        var name = button.data("real-name");
        var typeItem = button.data("type");
        var row = button.closest("tr");
        var domain = $('#delete-ip-btn').data('domain');  // Obtendo o domínio do elemento

        button.text("Instalando...").prop("disabled", true);

        // Fazendo a requisição para instalar o plugin/tema
        $.ajax({
            url: ajaxurl,
            type: "POST",
            data: {
                action: "wpgpl_child_download_and_install",
                name: name,
                type: typeItem,
                domain: domain  // Enviando o domínio
            },
            success: function(response) {
                if (response.success) {
                    button.text("Instalado");

                    // Atualiza a interface visual
                    var newVersion = row.find(".wpgpl-vault-api-version span").text();
                    row.find(".wpgpl-vault-current-version .version-text").text(newVersion);
                    row.find(".wpgpl-vault-api-version").text("");
                    row.find(".wpgpl-vault-api-download").html("");
                    row.find(".wpgpl-vault-status").html('<span style="background-color: #23c55e; color: #fff; font-weight: 600; padding: 4px 6px; border-radius: 4px;">Atualizado</span>');
                } else {
                    button.text("Erro ao instalar: " + response.data);
                }
            },
            error: function() {
                button.text("Erro na requisição");
            }
        });
    });

    // Função para instalar versões antigas
    $(document).on("click", ".wpgpl-vault-install-old-version", function() {
        var button = $(this);
        var dropdown = button.siblings(".wpgpl-vault-old-version-dropdown");
        var selectedVersion = dropdown.val();
        var name = button.closest("tr").find(".wpgpl-vault-check").data("real-name");
        var typeItem = button.closest("tr").find(".wpgpl-vault-check").data("type");
        var row = button.closest("tr");
        var domain = $('#delete-ip-btn').data('domain');  // Obtendo o domínio do elemento

        button.text("Instalando...").prop("disabled", true);

        // Fazendo a requisição para instalar a versão antiga
        $.ajax({
            url: ajaxurl,
            type: "POST",
            data: {
                action: "wpgpl_child_download_and_install",
                name: name,
                type: typeItem,
                version: selectedVersion,
                domain: domain  // Enviando o domínio
            },
            success: function(response) {
                if (response.success) {
                    button.text("Instalado");

                    // Atualiza a interface visual
                    row.find(".wpgpl-vault-current-version .version-text").text(selectedVersion);
                    row.find(".wpgpl-vault-api-version").text("");
                    row.find(".wpgpl-vault-api-download").html("");
                    row.find(".wpgpl-vault-api-old-download").html(""); // Remove o dropdown e botão após instalação
                    row.find(".wpgpl-vault-status").html('<span style="background-color: #23c55e; color: #fff; font-weight: 600; padding: 4px 6px; border-radius: 4px;">Revertido</span>');
                } else {
                    button.text("Erro ao instalar: " + response.data);
                }
            },
            error: function() {
                button.text("Erro na requisição");
            }
        });
    });

    function versionCompare(v1, v2) {
    if (typeof v1 !== 'string' || typeof v2 !== 'string') return false;

    // Função auxiliar para lidar com partes numéricas e alfanuméricas
    function parsePart(part) {
        var result = [];
        part.replace(/(\d+|[a-zA-Z]+)/g, function(match) {
            // Se for um número, converte para inteiro, senão mantém como string
            result.push(isNaN(match) ? match : parseInt(match, 10));
        });
        return result;
    }

    // Função para comparar as partes (tanto numéricas quanto alfanuméricas)
    function compareParts(p1, p2) {
        for (var i = 0; i < Math.max(p1.length, p2.length); i++) {
            var a = p1[i] || 0;
            var b = p2[i] || 0;

            if (typeof a === 'number' && typeof b === 'number') {
                if (a > b) return 1;
                if (a < b) return -1;
            } else {
                // Comparação alfabética para partes que não são números
                a = a.toString();
                b = b.toString();
                if (a > b) return 1;
                if (a < b) return -1;
            }
        }

        return 0;
    }

    // Divida as versões em suas partes principais e subversões
    var v1parts = v1.split('-').map(part => parsePart(part));
    var v2parts = v2.split('-').map(part => parsePart(part));

    // Compare os números principais da versão (antes do sufixo alfanumérico, se houver)
    var result = compareParts(v1parts[0], v2parts[0]);
    if (result !== 0) return result;

    // Compare as partes após o sufixo, se existirem
    return compareParts(v1parts[1] || [], v2parts[1] || []);
    }
});