jQuery(document).ready(function($) {
    // Função para reverter o estado do checkbox e atualizar a cor do switch
    function revertCheckbox(checkbox, shouldBeChecked) {
        checkbox.prop("checked", shouldBeChecked);
        checkbox.next(".slider").toggleClass("ajax-success", shouldBeChecked);
    }

    // Função para alternar a atualização automática de plugins ou temas
    function toggleAutoUpdate(checkbox, action, entity, enabled) {
        checkbox.prop("disabled", true); // Desabilita o checkbox durante a ação

        var previousChecked = checkbox.is(":checked");
        revertCheckbox(checkbox, !previousChecked); // Reverte o estado visual temporariamente

        var data = {
            action: action,
            security: $("#wpgpl_vault_nonce_field").val(),
            enabled: enabled
        };

        // Verifica se é plugin ou tema e adiciona o dado correspondente
        if (entity === "plugin_cron") {
            data["plugin_cron_enabled"] = enabled;
        } else if (entity === "theme_cron") {
            data["theme_cron_enabled"] = enabled;
        } else if (entity === "plugin") {
            data["plugin"] = checkbox.data("plugin"); // Extrai o nome do plugin
        } else if (entity === "theme") {
            data["theme"] = checkbox.data("theme"); // Extrai o nome do tema
        } else {
            data[entity] = checkbox.data(entity); // Atribui o valor correto baseado no tipo
        }

        $.ajax({
            url: ajaxurl,
            type: "POST",
            data: data,
            success: function(response) {
                if (response.success) {
                    console.log(`Settings saved for ${entity}:`, checkbox.data(entity) || "");
                    revertCheckbox(checkbox, enabled); // Atualiza o estado visual com o resultado real
                } else {
                    console.log(`Failed to save settings for ${entity}:`, checkbox.data(entity) || "");
                    revertCheckbox(checkbox, previousChecked); // Reverte ao estado anterior se falhou
                }
                checkbox.prop("disabled", false); // Reabilita o checkbox após a ação
                checkbox.next(".slider").toggleClass("ajax-success", checkbox.is(":checked")); // Atualiza a cor do slider
                checkbox.trigger("toggleComplete"); // Dispara um evento para indicar a conclusão do AJAX
            },
            error: function() {
                console.log(`Error in AJAX request for ${entity}:`, checkbox.data(entity) || "");
                revertCheckbox(checkbox, previousChecked); // Reverte ao estado anterior em caso de erro
                checkbox.prop("disabled", false); // Reabilita o checkbox após erro
                checkbox.next(".slider").toggleClass("ajax-success", checkbox.is(":checked")); // Atualiza a cor do slider
                checkbox.trigger("toggleComplete"); // Dispara um evento para indicar a conclusão do AJAX
            },
        });
    }

    // Processar atualização automática em sequência para ações em massa
    function toggleAutoUpdateInSequence(items, action, enabled, callback) {
        if (items.length === 0) {
            if (callback) callback();
            return;
        }

        var currentItem = items.shift();
        var checkbox = currentItem;

        // Determina o tipo (plugin ou theme) e atribui o valor correto ao checkbox
        var entityType = checkbox.data("plugin") ? "plugin" : "theme";

        toggleAutoUpdate(checkbox, action, entityType, enabled);

        // Aguarda a finalização da ativação/desativação atual antes de iniciar a próxima
        checkbox.one("toggleComplete", function() {
            toggleAutoUpdateInSequence(items, action, enabled, callback); // Chama recursivamente até terminar todos os itens
        });
    }

    // Manipuladores de evento para capturar a ação de alternar individualmente
    $("#plugin_cron_enabled").on("change", function() {
        var checkbox = $(this);
        toggleAutoUpdate(checkbox, "save_wpgpl_vault_plugin_cron", "plugin_cron", checkbox.is(":checked") ? 1 : 0);
    });

    $("#theme_cron_enabled").on("change", function() {
        var checkbox = $(this);
        toggleAutoUpdate(checkbox, "save_wpgpl_vault_theme_cron", "theme_cron", checkbox.is(":checked") ? 1 : 0);
    });

    $(document).on("change", ".auto-update-plugin", function() {
        var checkbox = $(this);
        toggleAutoUpdate(checkbox, "save_wpgpl_vault_auto_update_plugin", "plugin", checkbox.is(":checked") ? 1 : 0);
    });

    $(document).on("change", ".auto-update-theme", function() {
        var checkbox = $(this);
        toggleAutoUpdate(checkbox, "save_wpgpl_vault_auto_update_theme", "theme", checkbox.is(":checked") ? 1 : 0);
    });

    // Inicializa o estado dos checkboxes com a cor correta
    function initializeCheckboxState() {
         if ($("#plugin_cron_enabled").data("enabled") == 1) {
            $("#plugin_cron_enabled").prop("checked", true).next(".slider").addClass("ajax-success");
        }
        if ($("#theme_cron_enabled").data("enabled") == 1) {
            $("#theme_cron_enabled").prop("checked", true).next(".slider").addClass("ajax-success");
        }
        $(".auto-update-plugin, .auto-update-theme").each(function() {
            if ($(this).is(":checked")) {
                $(this).next(".slider").addClass("ajax-success");
            }
        });
    }

    initializeCheckboxState();

    // Selecione/Deselecione todos os plugins e desmarque temas
    $('#select-all-plugins').on('click', function() {
        var checked = $(this).is(':checked');
        $('.plugin-select').each(function() {
            $(this).prop('checked', checked);
        });
        // Desmarcar temas e o checkbox "select all themes"
        $('#select-all-themes').prop('checked', false);
        $('.theme-select').prop('checked', false);
    });

    // Selecione/Deselecione todos os temas e desmarque plugins
    $('#select-all-themes').on('click', function() {
        var checked = $(this).is(':checked');
        $('.theme-select').each(function() {
            $(this).prop('checked', checked);
        });
        // Desmarcar plugins e o checkbox "select all plugins"
        $('#select-all-plugins').prop('checked', false);
        $('.plugin-select').prop('checked', false);
    });

    // Desmarcar plugins quando um tema é selecionado
    $('.theme-select').on('change', function() {
        if ($(this).is(':checked')) {
            $('#select-all-plugins').prop('checked', false);
            $('.plugin-select').prop('checked', false);
        }
    });

    // Desmarcar temas quando um plugin é selecionado
    $('.plugin-select').on('change', function() {
        if ($(this).is(':checked')) {
            $('#select-all-themes').prop('checked', false);
            $('.theme-select').prop('checked', false);
        }
    });

    // Função para verificar um item por vez no bulk action
    function verifyItemInSequence(items, callback) {
        if (items.length === 0) {
            if (callback) callback();
            return;
        }

        var currentItem = items.shift();
        var button = currentItem.closest("tr").find(".wpgpl-vault-check");

        button.trigger("click"); // Dispara o evento de clique no botão de verificação

        // Aguarda a finalização da verificação atual antes de iniciar a próxima
        button.one("ajaxComplete", function() {
            verifyItemInSequence(items, callback); // Chama recursivamente até terminar todos os itens
        });
    }

    // Bulk actions para plugins e temas
    $('#doaction').on('click', function() {
        var action = $('#bulk-action-selector-top').val(); // Obtém a ação selecionada no dropdown
        var selectedPlugins = [];
        var selectedThemes = [];

        // Coleta plugins selecionados
        $('.plugin-select:checked').each(function() {
            selectedPlugins.push($(this).closest('tr').find('.auto-update-plugin'));
        });

        // Coleta temas selecionados
        $('.theme-select:checked').each(function() {
            selectedThemes.push($(this).closest('tr').find('.auto-update-theme'));
        });

        if (action === '-1') {
            alert('Por favor, selecione uma ação em massa.');
            return;
        }

        if (selectedPlugins.length === 0 && selectedThemes.length === 0) {
            alert('Por favor, selecione pelo menos um plugin ou tema.');
            return;
        }

        switch (action) {
            case 'activate-auto-update':
                toggleAutoUpdateInSequence(selectedPlugins, 'save_wpgpl_vault_auto_update_plugin', 1);
                toggleAutoUpdateInSequence(selectedThemes, 'save_wpgpl_vault_auto_update_theme', 1);
                break;
            case 'disable-auto-update':
                toggleAutoUpdateInSequence(selectedPlugins, 'save_wpgpl_vault_auto_update_plugin', 0);
                toggleAutoUpdateInSequence(selectedThemes, 'save_wpgpl_vault_auto_update_theme', 0);
                break;
            case 'verify-update':
                var allItems = selectedPlugins.concat(selectedThemes);
                verifyItemInSequence(allItems);
                break;
            default:
                alert('Ação inválida.');
        }
    });

    // Verificar API ao clicar no botão de verificação
    $(".wpgpl-vault-check").on("click", function() {
        var button = $(this);
        var name = button.data("real-name");
        var typeItem = button.data("type");
        var row = button.closest("tr");
        var currentVersion = row.find(".wpgpl-vault-current-version .version-text").text();
        var resultVersion = row.find(".wpgpl-vault-api-version");
        var resultDownload = row.find(".wpgpl-vault-api-download");
        var resultStatus = row.find(".wpgpl-vault-status");
        var resultVirusTotal = row.find(".wpgpl-vault-virus-total");
        var resultOldDownload = row.find(".wpgpl-vault-api-old-download");
        button.text("Verificando...").prop("disabled", true);

        $.ajax({
            url: ajaxurl,
            type: "GET",
            data: {
                action: "wpgpl_vault_check_api",
                name: name
            },
            success: function(response) {
                if (response.success && response.data.length > 0) {
                    var data = response.data[0];
                    var apiVersion = data.version;
                    var oldVersions = data.old_versions;
                    var virusReport = data.virus_total_report;
                    var itemPath = button.data("path");

                    resultVersion.text(apiVersion).wrapInner("<span></span>").find("span").css({
                        "background-color": "#23c55e",
                        color: "#fff",
                        "font-weight": "600",
                        padding: "4px 6px",
                        "border-radius": "4px"
                    });

                    if (versionCompare(currentVersion, apiVersion) < 0) {
                        $.ajax({
                            url: ajaxurl,
                            type: "POST",
                            data: {
                                action: "wpgpl_vault_store_outdated_item",
                                security: $("#wpgpl_vault_nonce_field").val(),
                                name: name,
                                version: apiVersion,
                                current_version: currentVersion,
                                path: itemPath
                            },
                            success: function() {
                                console.log("Item desatualizado armazenado com sucesso");
                            },
                        });
                        resultStatus.text("Desatualizado").wrapInner("<span></span>").find("span").css({
                            "background-color": "#e30047",
                            color: "#fff",
                            "font-weight": "600",
                            padding: "4px 6px",
                            "border-radius": "4px"
                        });
                        resultDownload.html('<button class="wpgpl-vault-download button" data-type="' + typeItem + '" data-real-name="' + name + '"><i class="fas fa-download"></i> Download e Instalar</button>');
                    } else if (versionCompare(currentVersion, apiVersion) > 0) {
                        $.ajax({
                            url: ajaxurl,
                            type: "POST",
                            data: {
                                action: "wpgpl_vault_remove_outdated_item",
                                security: $("#wpgpl_vault_nonce_field").val(),
                                name: name,
                                version: apiVersion,
                                current_version: currentVersion,
                                path: itemPath
                            },
                            success: function() {
                                console.log("Item obsoleto removido com sucesso");
                            },
                        });
                        resultStatus.text("Obsoleta").wrapInner("<span></span>").find("span").css({
                            "background-color": "#ffa500",
                            color: "#fff",
                            "font-weight": "600",
                            padding: "4px 6px",
                            "border-radius": "4px"
                        });
                        resultVersion.text(apiVersion).wrapInner("<span></span>").find("span").css({
                            "background-color": "#ffa500", // Define o fundo laranja para resultVersion
                            color: "#fff",
                            "font-weight": "600",
                            padding: "4px 6px",
                            "border-radius": "4px"
                        });
                        resultDownload.html("");
                    } else {
                        $.ajax({
                            url: ajaxurl,
                            type: "POST",
                            data: {
                                action: "wpgpl_vault_remove_outdated_item",
                                security: $("#wpgpl_vault_nonce_field").val(),
                                name: name,
                                version: apiVersion,
                                current_version: currentVersion,
                                path: itemPath
                            },
                            success: function() {
                                console.log("Item atualizado removido com sucesso");
                            },
                        });
                        resultStatus.text("Atualizado").wrapInner("<span></span>").find("span").css({
                            "background-color": "#23c55e",
                            color: "#fff",
                            "font-weight": "600",
                            padding: "4px 6px",
                            "border-radius": "4px"
                        });
                        resultDownload.html("");
                    }

                    if (virusReport) {
                        resultVirusTotal.html('<button class="button virus-total-report-button" onclick="window.open(\'' + virusReport + "', '_blank')\"><i class=\"fas fa-file-alt\"></i> Ver Relatório</button>");
                    } else {
                        resultVirusTotal.html("Relatório não disponível");
                    }

                    if (oldVersions && oldVersions.length > 0) {
                        oldVersions.sort(function(a, b) {
                            return b.old_version.localeCompare(a.old_version, undefined, { numeric: true, sensitivity: 'base' });
                        });
                        var dropdownHtml = '<select class="wpgpl-vault-old-version-dropdown">';
                        oldVersions.forEach(function(version) {
                            dropdownHtml += '<option value="' + version.old_version + '">' + version.old_version + '</option>';
                        });
                        dropdownHtml += '</select>';
                        dropdownHtml += '<button class="wpgpl-vault-install-old-version button"><i class="fas fa-download"></i> Instalar Versão ' + oldVersions[0].old_version + '</button>';
                        resultOldDownload.html(dropdownHtml);

                        resultOldDownload.find(".wpgpl-vault-old-version-dropdown").on("change", function() {
                            var selectedVersion = $(this).val();
                            resultOldDownload.find(".wpgpl-vault-install-old-version").html('<i class="fas fa-download"></i> Instalar Versão ' + selectedVersion);
                        });
                    } else {
                        resultOldDownload.html("Não disponível");
                    }
                } else {
                    resultVersion.text("Não encontrado").wrapInner("<span></span>").find("span").css({
                        "background-color": "#e30047",
                        color: "#fff",
                        "font-weight": "600",
                        padding: "4px 6px",
                        "border-radius": "4px"
                    });
                    resultDownload.text("");
                    resultStatus.text("");
                }
                button.html('<i class="fas fa-check-circle"></i> Verificado').prop("disabled", false);
                button.trigger("ajaxComplete"); // Dispara um evento para indicar a conclusão do AJAX
            },
            error: function() {
                resultVersion.text("Erro na requisição");
                resultDownload.text("");
                resultStatus.text("");
                button.text("Verificado").prop("disabled", false);
                button.trigger("ajaxComplete"); // Dispara um evento para indicar a conclusão do AJAX
            },
        });
    });
   
    // Adicionar o evento de clique para o botão de instalação da versão antiga
    $(document).on("click", ".wpgpl-vault-install-old-version", function() {
        var button = $(this);
        var dropdown = button.siblings(".wpgpl-vault-old-version-dropdown");
        var selectedVersion = dropdown.val();
        var name = button.closest("tr").find(".wpgpl-vault-check").data("real-name");
        var typeItem = button.closest("tr").find(".wpgpl-vault-check").data("type");
        var row = button.closest("tr");

        button.text("Instalando...").prop("disabled", true);

        $.ajax({
            url: ajaxurl,
            type: "POST",
            data: {
                action: "wpgpl_vault_download_and_install",
                name: name,
                type: typeItem,
                version: selectedVersion
            },
            success: function(response) {
                try {
                    // Tenta capturar o JSON dentro do HTML
                    var jsonResponse = response.match(/\{.*\}/);

                    if (jsonResponse) {
                        // Faz o parse da resposta
                        var parsedResponse = JSON.parse(jsonResponse[0]);

                        if (parsedResponse.success) {
                            button.text("Instalado");
                            $.ajax({
                                url: ajaxurl,
                                type: "POST",
                                data: {
                                    action: "wpgpl_vault_remove_outdated_item",
                                    security: $("#wpgpl_vault_nonce_field").val(),
                                    name: name
                                },
                                success: function() {
                                    console.log("Item atualizado removido com sucesso");
                                    var newVersion = dropdown.val();
                                    row.find(".wpgpl-vault-current-version .version-text").text(newVersion);
                                    row.find(".wpgpl-vault-api-version").text("");
                                    row.find(".wpgpl-vault-api-download").html("");
                                    row.find(".wpgpl-vault-api-old-download").html(""); // Remove o dropdown e botão após instalação
                                    row.find(".wpgpl-vault-status").html('<span style="background-color: #23c55e; color: #fff; font-weight: 600; padding: 4px 6px; border-radius: 4px;">Revertido</span>');
                                },
                            });
                        } else {
                            button.text("Erro ao instalar: " + (parsedResponse.data ? parsedResponse.data : "Erro desconhecido"));
                        }
                    } else {
                        button.text("Erro na resposta do servidor");
                    }
                } catch (e) {
                    button.text("Erro ao processar a resposta");
                }
            },
            error: function() {
                button.text("Erro na requisição");
            },
        });
    });

    function versionCompare(v1, v2) {
    if (typeof v1 !== 'string' || typeof v2 !== 'string') return false;

    // Função auxiliar para lidar com partes numéricas e alfanuméricas
    function parsePart(part) {
        var result = [];
        part.replace(/(\d+|[a-zA-Z]+)/g, function(match) {
            // Se for um número, converte para inteiro, senão mantém como string
            result.push(isNaN(match) ? match : parseInt(match, 10));
        });
        return result;
    }

    // Função para comparar as partes (tanto numéricas quanto alfanuméricas)
    function compareParts(p1, p2) {
        for (var i = 0; i < Math.max(p1.length, p2.length); i++) {
            var a = p1[i] || 0;
            var b = p2[i] || 0;

            if (typeof a === 'number' && typeof b === 'number') {
                if (a > b) return 1;
                if (a < b) return -1;
            } else {
                // Comparação alfabética para partes que não são números
                a = a.toString();
                b = b.toString();
                if (a > b) return 1;
                if (a < b) return -1;
            }
        }

        return 0;
    }

    // Divida as versões em suas partes principais e subversões
    var v1parts = v1.split('-').map(part => parsePart(part));
    var v2parts = v2.split('-').map(part => parsePart(part));

    // Compare os números principais da versão (antes do sufixo alfanumérico, se houver)
    var result = compareParts(v1parts[0], v2parts[0]);
    if (result !== 0) return result;

    // Compare as partes após o sufixo, se existirem
    return compareParts(v1parts[1] || [], v2parts[1] || []);
}

    // Adicionar o evento de clique para o botão de download
    $(document).on("click", ".wpgpl-vault-download", function() {
        var button = $(this);
        var name = button.data("real-name");
        var typeItem = button.data("type");
        var row = button.closest("tr");
        button.text("Instalando...").prop("disabled", true);
        $.ajax({
            url: ajaxurl,
            type: "POST",
            data: {
                action: "wpgpl_vault_download_and_install",
                name: name,
                type: typeItem
            },
            success: function(response) {
                try {
                    // Tenta capturar o JSON dentro do HTML
                    var jsonResponse = response.match(/\{.*\}/);

                    if (jsonResponse) {
                        // Faz o parse da resposta
                        var parsedResponse = JSON.parse(jsonResponse[0]);

                        if (parsedResponse.success) {
                            button.text("Instalado");
                            $.ajax({
                                url: ajaxurl,
                                type: "POST",
                                data: {
                                    action: "wpgpl_vault_remove_outdated_item",
                                    security: $("#wpgpl_vault_nonce_field").val(),
                                    name: name
                                },
                                success: function() {
                                    console.log("Item atualizado removido com sucesso");
                                    var newVersion = row.find(".wpgpl-vault-api-version span").text();
                                    row.find(".wpgpl-vault-current-version .version-text").text(newVersion);
                                    row.find(".wpgpl-vault-api-version").text("");
                                    row.find(".wpgpl-vault-api-download").html("");
                                    row.find(".wpgpl-vault-status").html('<span style="background-color: #23c55e; color: #fff; font-weight: 600; padding: 4px 6px; border-radius: 4px;">Atualizado</span>');
                                },
                            });
                        } else {
                            button.text("Erro ao instalar: " + (parsedResponse.data ? parsedResponse.data : "Erro desconhecido"));
                        }
                    } else {
                        button.text("Erro na resposta do servidor");
                    }
                } catch (e) {
                    button.text("Erro ao processar a resposta");
                }
            },
            error: function() {
                button.text("Erro na requisição");
            },
        });
    });
});