jQuery(document).ready(function($) {
    var currentPage = 1;
    var totalPages = 1; // Inicialmente, assumimos que há pelo menos uma página

    function loadHistory(page) {
        $.ajax({
            url: ajaxurl, // URL AJAX padrão do WordPress
            type: 'POST',
            data: {
                action: 'load_history',
                page: page
            },
            success: function(response) {
                if (response.success) {
                    $('#history-table-body').html(response.data.content);
                    $('#current-page').text(page);
                    totalPages = response.data.total_pages;
                    currentPage = page;

                    if (page > totalPages) {
                        $('#history-table-body').html('<tr><td colspan="3" style="text-align:center;">Nenhum registro encontrado.</td></tr>');
                        $('#current-page').hide();
                    } else {
                        $('#current-page').show();
                    }

                    updateUrl(page);
                } else {
                    alert('Erro ao carregar dados: ' + response.data);
                }
                updatePaginationControls();
            }
        });
    }

    function updateUrl(page) {
        var currentUrl = new URL(window.location.href);
        currentUrl.searchParams.set('paged', page);
        history.pushState({page: page}, null, currentUrl.toString());
    }

    function updatePaginationControls() {
        var paginationHTML = '';

        if (currentPage > 1) {
            paginationHTML += '<button id="prev-page"><i class="fa-solid fa-angle-left"></i> <span>Anterior</span></button>';
        }

        for (let i = 1; i <= totalPages; i++) {
            if (i === 1 || i === totalPages || (i >= currentPage - 1 && i <= currentPage + 1)) {
                var currentClass = (i === currentPage) ? 'current-page' : '';
                paginationHTML += '<span class="page-number ' + currentClass + '" data-page="' + i + '">' + i + '</span>';
            } else if (i === currentPage - 2 || i === currentPage + 2) {
                paginationHTML += '<span>...</span>';
            }
        }

        if (currentPage < totalPages) {
            paginationHTML += '<button id="next-page"><span>Próximo</span> <i class="fa-solid fa-angle-right"></i></button>';
        }

        $('.pagination-controls').html(paginationHTML);

        $('#prev-page').click(function() {
            if (currentPage > 1) {
                loadHistory(currentPage - 1);
            }
        });

        $('#next-page').click(function() {
            if (currentPage < totalPages) {
                loadHistory(currentPage + 1);
            }
        });

        $('.page-number').click(function() {
            var page = $(this).data('page');
            loadHistory(page);
        });
    }

    $('#next-page').click(function() {
        if (currentPage < totalPages) {
            loadHistory(currentPage + 1);
        }
    });

    $('#prev-page').click(function() {
        if (currentPage > 1) {
            loadHistory(currentPage - 1);
        }
    });

    function loadInitialPage() {
        var urlParams = new URLSearchParams(window.location.search);
        var page = urlParams.get('paged');
        if (page && !isNaN(page)) {
            page = parseInt(page);
            loadHistory(page);
        } else {
            loadHistory(currentPage);
        }
    }

    loadInitialPage();

    window.onpopstate = function(event) {
        if (event.state && event.state.page) {
            loadHistory(event.state.page);
        } else {
            loadHistory(1);
        }
    };
});
