<?php

if (!defined('ABSPATH')) {
    exit;
}

function wpgpl_vault_menu() {
    
    $icon_content = wpgpl_get_icon($GLOBALS['wpgpl_plugin_icon_url']);

    if ($icon_content !== false) {
        $icon_data = 'data:image/svg+xml;base64,' . base64_encode($icon_content);
    } else {

        $icon_data = 'data:image/svg+xml;base64,' . base64_encode('<svg><!-- Icon not available --></svg>');
    }
    
    add_menu_page(
        $GLOBALS['wpgpl_plugin_name'], // Título da página
        $GLOBALS['wpgpl_plugin_name'], // Título do menu
        'manage_options', // Capacidade
        $GLOBALS['wpgpl_plugin_slug'], // Slug do menu
        'wpgpl_vault_page', // Função que exibe o conteúdo
        $icon_data, // Ícone do menu
        66 // Posição no menu
    );

    $plugin_name = $GLOBALS['wpgpl_plugin_name'];
    if ($plugin_name === 'WPGPL Vault') {
        add_submenu_page(
            null, // Não adiciona ao menu
            'Ativação ' . $GLOBALS['wpgpl_plugin_name'], // Título da página
            null, // Não adiciona ao menu
            'manage_options', // Capacidade
            $GLOBALS['wpgpl_plugin_slug'] . '-activation', // Slug do menu
            'wpgpl_vault_activation_page' // Função que exibe o conteúdo
        );
    }
    
    add_submenu_page(
            null, // Não adiciona ao menu
            'Histórico', // Título da página
            null, // Não adiciona ao menu
            'manage_options', // Capacidade
            $GLOBALS['wpgpl_plugin_slug'] . '-history', // Slug do menu
            'wpgpl_vault_history_page' // Função que exibe o conteúdo
    );
    
    add_submenu_page(
            null, // Não adiciona ao menu
            'Backup', // Título da página
            null, // Não adiciona ao menu
            'manage_options', // Capacidade
            $GLOBALS['wpgpl_plugin_slug'] . '-backup', // Slug do menu
            'wpgpl_vault_backup_page' // Função que exibe o conteúdo
    );
    
    add_submenu_page(
            null, // Não adiciona ao menu
            'Multisites', // Título da página
            null, // Não adiciona ao menu
            'manage_options', // Capacidade
            $GLOBALS['wpgpl_plugin_slug'] . '-multisites', // Slug do menu
            'wpgpl_vault_multisites_page' // Função que exibe o conteúdo
    );
    
    add_submenu_page(
            null, 
            'Multisites by Domain', 
            null, 
            'manage_options', 
            $GLOBALS['wpgpl_plugin_slug'] . '-domain', 
            'wpgpl_vault_multisites_by_domain_page' 
    );

    add_action('current_screen', function() {
        $screen = get_current_screen();
        if ($screen && in_array($screen->id, [
            'toplevel_page_' . $GLOBALS['wpgpl_plugin_slug'],
            'admin_page_' . $GLOBALS['wpgpl_plugin_slug'] . '-activation',
            'admin_page_' . $GLOBALS['wpgpl_plugin_slug'] . '-backup',
            'admin_page_' . $GLOBALS['wpgpl_plugin_slug'] . '-multisites',
            'admin_page_' . $GLOBALS['wpgpl_plugin_slug'] . '-history',
            'admin_page_' . $GLOBALS['wpgpl_plugin_slug'] . '-domain'
        ])) {
            add_filter('qm/process', '__return_false', 10, 0);
        }
    });
}
add_action('admin_menu', 'wpgpl_vault_menu');

function wpgpl_vault_page() {
    include WPGPL_PLUGIN_PATH . 'templates/admin-page.php';
}

function wpgpl_vault_activation_page() {
    include WPGPL_PLUGIN_PATH . 'templates/activation-page.php';
}

function wpgpl_vault_history_page() {
    include WPGPL_PLUGIN_PATH . 'templates/history-page.php';
}

function wpgpl_vault_backup_page() {
    include WPGPL_PLUGIN_PATH . 'templates/backup-page.php';
}

function wpgpl_vault_multisites_page() {
    include WPGPL_PLUGIN_PATH . 'templates/multisites-page.php';
}

function wpgpl_vault_multisites_by_domain_page() {
    include WPGPL_PLUGIN_PATH . 'templates/admin-page-by-domain.php';
}

function wpgpl_custom_admin_title($admin_title, $title) {

    $screen = get_current_screen();

    if ($screen && strpos($screen->id, $GLOBALS['wpgpl_plugin_slug']) !== false) {

        $admin_title = $GLOBALS['wpgpl_plugin_name'];
        $title = $GLOBALS['wpgpl_plugin_name'];
    }

    return $admin_title;
}
add_filter('admin_title', 'wpgpl_custom_admin_title', 10, 2);