<?php

if (!defined('ABSPATH')) {
    exit;
}

function wpgpl_vault_create_table() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'wpgpl_vault_options';

    $charset_collate = $wpdb->get_charset_collate();

    $sql = "CREATE TABLE $table_name (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        option_name varchar(191) NOT NULL,
        option_value longtext NOT NULL,
        PRIMARY KEY  (id),
        UNIQUE KEY option_name (option_name)
    ) $charset_collate;";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
}

function wpgpl_vault_get_option($option_name, $default = null) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'wpgpl_vault_options';
    
    $query = $wpdb->prepare(
        "SELECT option_value FROM $table_name WHERE option_name = %s",
        $option_name
    );

    $result = $wpdb->get_var($query);

    if ($result !== null) {
        return maybe_unserialize($result);
    }

    return $default;
}

function wpgpl_vault_delete_option($option_name) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'wpgpl_vault_options';
    
    $wpdb->delete(
        $table_name,
        array('option_name' => $option_name),
        array('%s')
    );
}

function wpgpl_vault_update_option($option_name, $option_value) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'wpgpl_vault_options';

    $existing_option = $wpdb->get_var($wpdb->prepare(
        "SELECT COUNT(*) FROM $table_name WHERE option_name = %s",
        $option_name
    ));

    if ($existing_option > 0) {
        $result = $wpdb->update(
            $table_name,
            array('option_value' => maybe_serialize($option_value)),
            array('option_name' => $option_name),
            array('%s'),
            array('%s')
        );
        return $result !== false;
    } else {
        $result = $wpdb->insert(
            $table_name,
            array(
                'option_name' => $option_name,
                'option_value' => maybe_serialize($option_value)
            ),
            array('%s', '%s')
        );
        return $result !== false;
    }
}

function wpgpl_get_white_label_option($option_name, $default_value) {

    $option_value = wpgpl_vault_get_option($option_name);

    return $option_value ? $option_value : $default_value;
}
?>
