<?php

if (!defined('ABSPATH')) {
    exit;
}

function wpgpl_vault_check_license() {
    $license_key = $GLOBALS['wpgpl_license_key'];

    if (empty($license_key)) {
        error_log('WPGPL Vault License Check: Nenhuma chave de licença encontrada.');
        // Adiciona uma entrada ao histórico para falta de chave de licença
        $action = 'Verificação de Licença';
        $content = 'Nenhuma chave de licença encontrada durante a verificação.';
        wpgpl_vault_add_to_history($action, $content);
        return;
    }

    // Fazer a requisição para verificar a licença
    $response = wp_remote_get(
        wpgpl_vault_get_endpoint_url(ENDPOINT_CHECK_LICENSE) . '?license_key=' . urlencode($license_key), 
        array(
            'timeout' => 30
        )
    );

    if (is_wp_error($response)) {
        error_log('WPGPL Vault License Check: Erro na requisição.');
        // Adiciona uma entrada ao histórico para erro na requisição
        $action = 'Erro na Verificação de Licença';
        $content = 'Erro na requisição para verificar a licença.';
        wpgpl_vault_add_to_history($action, $content);
        return;
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    if (!$data['is_valid']) {
        wpgpl_vault_delete_option('wpgpl_vault_license_key');
        wpgpl_vault_delete_option('wpgpl_vault_uuid');
        error_log('WPGPL Vault License Check: Licença inválida. Chave de licença removida.');

        // Adiciona uma entrada ao histórico para licença inválida
        $action = 'Licença Inválida';
        $content = 'A chave de licença foi considerada inválida e removida do sistema.';
        wpgpl_vault_add_to_history($action, $content);
    } else {
        error_log('WPGPL Vault License Check: Licença válida.');

        // Adiciona uma entrada ao histórico para licença válida
        $action = 'Licença Válida';
        $content = 'A chave de licença foi validada com sucesso.';
        wpgpl_vault_add_to_history($action, $content);
    }
}
add_action('wpgpl_vault_check_license_cron_job', 'wpgpl_vault_check_license');