<?php

if (!defined('ABSPATH')) {
    exit;
}

function wpgpl_add_to_archived_items($item) {
    $archived_items = wpgpl_vault_get_option('wpgpl_vault_archived_items', []);
    
    // Verifica se o item já existe no array com base no path
    foreach ($archived_items as $archived_item) {
        if ($archived_item['path'] === $item['path']) {
            // Se o item já existir, sai da função sem adicionar
            return;
        }
    }
    
    // Adiciona o novo item ao array
    $archived_items[] = $item;
    
    // Atualiza a opção com os itens arquivados
    wpgpl_vault_update_option('wpgpl_vault_archived_items', $archived_items);
    
    // Adiciona uma entrada ao histórico usando a função de histórico
    $action = 'Item Arquivado';
    $content = 'O item "' . $item['name'] . '" foi arquivado. Caminho: ' . $item['path'];
    wpgpl_vault_add_to_history($action, $content);
}

function wpgpl_remove_from_archived_items($path) {
    // Verifique se o caminho foi fornecido
    if (empty($path)) {
        return;
    }

    // Obtém os itens arquivados ou um array vazio se for null
    $archived_items = wpgpl_vault_get_option('wpgpl_vault_archived_items', []);

    // Garante que $archived_items seja sempre um array
    if (!is_array($archived_items)) {
        $archived_items = [];
    }

    // Procure o nome correspondente ao path com comparação insensível a maiúsculas/minúsculas
    $item_name = '';
    $found = false;
    foreach ($archived_items as $item) {
        // Usando strcasecmp para ignorar diferenças de maiúsculas/minúsculas
        if (isset($item['path']) && strcasecmp($item['path'], $path) === 0) {
            $item_name = isset($item['name']) ? $item['name'] : 'Nome não encontrado'; // Obtenha o nome do item
            $found = true;
            break;
        }
    }

    if (!$found) {
        return;
    }

    // Filtra os itens arquivados para remover o item com o path especificado
    $new_archived_items = array_filter($archived_items, function($item) use ($path) {
        return isset($item['path']) && strcasecmp($item['path'], $path) !== 0; // Usando comparação insensível a maiúsculas/minúsculas
    });

    // Atualiza a opção com os itens arquivados
    $update_result = wpgpl_vault_update_option('wpgpl_vault_archived_items', $new_archived_items);

    // Adiciona uma entrada ao histórico usando o nome do item ao invés do caminho
    $action = 'Item Desarquivado';
    $content = 'O item "' . $item_name . '" foi desarquivado.';
    $history_result = wpgpl_vault_add_to_history($action, $content);
}

add_action('deleted_theme', function($theme_name) {
    $theme_name = wp_get_theme($theme_name);
    wpgpl_remove_from_archived_items($theme_name);
});

add_action('deleted_plugin', function($plugin) {
    wpgpl_remove_from_archived_items($plugin); // $plugin é o caminho relativo do arquivo principal do plugin
});
