<?php

if (!defined('ABSPATH')) {
    exit;
}

function wpgpl_get_icon($url) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_FAILONERROR, true); // Retorna false em caso de erro
    $content = curl_exec($ch);
    curl_close($ch);

    return $content !== false ? $content : false;
}

function wpgpl_download_plugin_icon($icon_url, $save_path) {
    // Faz a requisição para baixar o arquivo
    $response = wp_remote_get($icon_url);

    // Verifica se não houve erro na requisição e se o código de resposta é 200 (OK)
    if (!is_wp_error($response) && wp_remote_retrieve_response_code($response) === 200) {
        $body = wp_remote_retrieve_body($response);

        // Verifica se o diretório existe, se não, cria
        $upload_dir = dirname($save_path);
        if (!file_exists($upload_dir)) {
            wp_mkdir_p($upload_dir);
        }

        // Salva o arquivo no caminho especificado
        file_put_contents($save_path, $body);

        // Verifica se o arquivo foi salvo corretamente
        return file_exists($save_path);
    }

    // Retorna falso se ocorrer algum erro
    return false;
}

function wpgpl_check_and_download_icon() {
    // Define o caminho onde o ícone deve estar
    $icon_path = WPGPL_PLUGIN_PATH . 'media/icon_whitelabel.svg';

    // Verifica se o arquivo de ícone já existe
    if (!file_exists($icon_path)) {
        // Se o arquivo não existe, busca a URL do ícone no banco de dados
        $icon_url = wpgpl_vault_get_option('wpgpl_plugin_icon_url');

        // Se a URL está definida e não está vazia, baixa o ícone
        if (!empty($icon_url)) {
            // Baixa o ícone e salva no caminho especificado
            wpgpl_download_plugin_icon($icon_url, $icon_path);
        }
    }
}
add_action('wp_loaded', 'wpgpl_check_and_download_icon');

function wpgpl_vault_check_products($products_names) {
    $license_key = $GLOBALS['wpgpl_license_key'];
    
    // Configurar o corpo da requisição
    $body = json_encode([
        'products' => $products_names
    ]);

    $response = wp_remote_post(wpgpl_vault_get_endpoint_url(ENDPOINT_ITEMS_CHECK), [
        'body' => $body,
        'headers' => [
            'Content-Type' => 'application/json',
            'Authorization' => $license_key
        ],
        'timeout' => 30 // Timeout de 30 segundos
    ]);

    // Verificar se houve algum erro na requisição
    if (is_wp_error($response)) {
        return ['error' => 'Erro na requisição: ' . $response->get_error_message()];
    }

    // Obter o corpo da resposta
    $response_body = wp_remote_retrieve_body($response);
    $result = json_decode($response_body, true);

    // Verificar se a resposta foi decodificada corretamente
    if (!is_array($result)) {
        return ['error' => 'Resposta JSON inválida recebida'];
    }

    // Se o JSON retornado tem algum formato diferente esperado, retornar um erro genérico
    if (!isset($result[0]['name']) || !isset($result[0]['exists'])) {
        return ['error' => 'Estrutura inesperada no JSON retornado'];
    }

    return $result;
}

function wpgpl_remove_outdated_item($identifier, $is_plugin = true) {
    
    $outdated_items = wpgpl_vault_get_option('wpgpl_vault_items_outdate', []);

    foreach ($outdated_items as $key => $item) {
        if (($is_plugin && $item['path'] === $identifier) || (!$is_plugin && $item['name'] === $identifier)) {

            wpgpl_vault_add_to_history('Item Removido', 'O item "' . $item['name'] . '" foi removido da lista de desatualizados.');
            
            unset($outdated_items[$key]);
            break;
        }
    }

    wpgpl_vault_update_option('wpgpl_vault_items_outdate', $outdated_items);
}

add_action('deleted_plugin', function($plugin) {
    $plugin_path = $plugin;
    wpgpl_remove_outdated_item($plugin_path, true);
});

add_action('deleted_theme', function($theme_name) {
    wpgpl_remove_outdated_item($theme_name, false);
});

function wpgpl_vault_plugin_row_meta_version($plugin_meta, $plugin_file) {
    global $GLOBALS;
    
    $plugin_name = $GLOBALS['wpgpl_plugin_name'];
    
    if ($plugin_file == WPGPL_PLUGIN_BASENAME) {
        $remote_version = wpgpl_vault_get_option('wpgpl_vault_remote_version');
        if ($remote_version && defined('WPGPL_VERSION') && version_compare($remote_version, WPGPL_VERSION, '>')) {
            $plugin_meta[] = '<span style="color:red;">' . sprintf(__('<b>%s:</b> O plugin está desatualizado. Versão disponível: v%s.', 'wpgpl-vault'), esc_html($plugin_name), esc_html($remote_version)) . '</span>';
        }
    }
    return $plugin_meta;
}
add_filter('plugin_row_meta', 'wpgpl_vault_plugin_row_meta_version', 10, 2);

function wpgpl_vault_plugin_action_links($links, $file) {
    if ($file == WPGPL_PLUGIN_BASENAME) {
        $license_key = $GLOBALS['wpgpl_license_key'];
        if (empty($license_key)) {
            $activation_link = '<a href="' . admin_url('admin.php?page=wpgpl-vault-activation') . '" style="color:green;">' . __('Ativar Licença', 'wpgpl-vault') . '</a>';
            array_unshift($links, $activation_link);
        }
    }
    return $links;
}
add_filter('plugin_action_links', 'wpgpl_vault_plugin_action_links', 10, 2);

function wpgpl_vault_plugin_row_meta_unlimited($plugin_meta, $plugin_file) {
    if ($plugin_file == WPGPL_PLUGIN_BASENAME) {
        $license_key = $GLOBALS['wpgpl_license_key'];
        
        if (empty($license_key)) {
            $plugin_meta[] = '<a href="https://wpgpl.com.br/pricing" style="color:red;" target="_blank">' . __('Seja Unlimited', 'wpgpl-vault') . '</a>';
        }
    }
    return $plugin_meta;
}
add_filter('plugin_row_meta', 'wpgpl_vault_plugin_row_meta_unlimited', 10, 2);