<?php

if (!defined('ABSPATH')) {
    exit;
}

function wpgpl_calculate_max_sites() {
    // Obter configurações do servidor
    $memory_limit = ini_get('memory_limit'); // ex: 128M
    $max_execution_time = ini_get('max_execution_time'); // em segundos
    $max_input_vars = ini_get('max_input_vars'); // número máximo de variáveis de entrada

    // Definir limites mínimos e máximos de sites com base nos recursos
    $min_sites = 5;
    $max_sites = 150;

    // Conversão do limite de memória para MB
    $unit = strtolower(substr($memory_limit, -1));
    $memory_limit_value = (int) $memory_limit;
    switch ($unit) {
        case 'g':
            $memory_limit_value *= 1024; // Converter GB para MB
            break;
        case 'k':
            $memory_limit_value /= 1024; // Converter KB para MB
            break;
    }

    // Cálculo básico para definir o número de sites permitidos com base nas variáveis
    $memory_factor = min(ceil($memory_limit_value / 128), 50); // Cada 128 MB permite 1 site, até um máximo de 50
    $time_factor = min(ceil($max_execution_time / 30), 50); // Cada 30 segundos permite 1 site, até um máximo de 50
    $input_factor = min(ceil($max_input_vars / 1000), 50); // Cada 1000 input vars permite 1 site, até um máximo de 50

    // Definir o número máximo de sites como a média dos três fatores
    $calculated_sites = ceil(($memory_factor + $time_factor + $input_factor) / 3);

    // Limitar o valor ao intervalo definido
    return max($min_sites, min($calculated_sites, $max_sites));
}