<?php
wpgpl_set_global_theme_variables(); // Chame esta função no início do script ou em um hook apropriado

$logo_url = $GLOBALS['wpgpl_plugin_slogan_url'];
$wpgpl_vault_name = $GLOBALS['wpgpl_plugin_name'];

global $wpgpl_theme_color;

// Determinar a seleção baseada no valor retornado
$selectedLight = ($wpgpl_theme_color === '1') ? 'selected' : '';
$selectedDark = ($wpgpl_theme_color === '0') ? 'selected' : '';
$selectedSystem = (!in_array($wpgpl_theme_color, ['0', '1'])) ? 'selected' : '';

// Obter os itens desatualizados armazenados
$outdated_items = wpgpl_vault_get_option('wpgpl_vault_items_outdate', []);

// Certifique-se de que $outdated_items é um array
if (!is_array($outdated_items)) {
    $outdated_items = [];
}
// Contar o número de itens no array
$outdated_count = is_array($outdated_items) ? count($outdated_items) : 0;

$current_site_url = wpgpl_get_current_site_from_url();

// Obter as informações do banco de dados para os multisites
$multisites_data = wpgpl_vault_get_option('wpgpl_multisites_data', []);

// Verificar se o site atual existe no array do banco de dados
$site_data = isset($multisites_data[$current_site_url]) ? $multisites_data[$current_site_url] : null;

if ($site_data) {
    // Informações sobre os plugins e temas do site atual
    $site_plugins = isset($site_data['plugins']) ? $site_data['plugins'] : [];
    $site_themes = isset($site_data['themes']) ? $site_data['themes'] : [];

    // Obter as configurações de atualização automática do site
    $plugin_cron_enabled = isset($site_data['site_info']['auto_update_plugins']) ? $site_data['site_info']['auto_update_plugins'] : 0;
    $theme_cron_enabled = isset($site_data['site_info']['auto_update_themes']) ? $site_data['site_info']['auto_update_themes'] : 0;
    $backup_enabled = isset($site_data['site_info']['backup_active']) ? $site_data['site_info']['backup_active'] : 0;

    // Obter plugins com auto atualização ativa
    $auto_update_plugins = array_filter($site_plugins, function($plugin) {
        return isset($plugin['auto_update']) && $plugin['auto_update'];
    });

    // Obter temas com auto atualização ativa
    $auto_update_themes = array_filter($site_themes, function($theme) {
        return isset($theme['auto_update']) && $theme['auto_update'];
    });

    // Obter itens arquivados
    $archived_items = array_merge(
        array_filter($site_plugins, function($plugin) {
            return isset($plugin['archived']) && $plugin['archived'];
        }),
        array_filter($site_themes, function($theme) {
            return isset($theme['archived']) && $theme['archived'];
        })
    );

    // Obter o nome do site
    $site_name = isset($site_data['site_info']['name']) ? $site_data['site_info']['name'] : 'Nome não encontrado';

    // Obter os nomes dos plugins e temas
    $site_plugin_names = array_map(function($plugin) {
        return $plugin['name'];
    }, $site_plugins);

    $site_theme_names = array_map(function($theme) {
        return $theme['name'];
    }, $site_themes);

    // Chamar a função da API para verificar plugins e temas no repositório
    $plugins_api_result = wpgpl_vault_check_products($site_plugin_names);
    $themes_api_result = wpgpl_vault_check_products($site_theme_names);

    // Verificar status de erro na resposta da API
    $plugins_status = [];
    $themes_status = [];

    if (!isset($plugins_api_result['error'])) {
        foreach ($plugins_api_result as $item) {
            $plugins_status[$item['name']] = $item['exists'];
        }
    }

    if (!isset($themes_api_result['error'])) {
        foreach ($themes_api_result as $item) {
            $themes_status[$item['name']] = $item['exists'];
        }
    }

    // Filtrar os plugins e temas para contar apenas os que não estão arquivados e existem no repositório
    $active_plugins = array_filter($site_plugins, function($plugin) use ($plugins_status) {
        return empty($plugin['archived']) && isset($plugins_status[$plugin['name']]) && $plugins_status[$plugin['name']];
    });

    $active_themes = array_filter($site_themes, function($theme) use ($themes_status) {
        return empty($theme['archived']) && isset($themes_status[$theme['name']]) && $themes_status[$theme['name']];
    });

    // Contagem de plugins e temas ativos e existentes no repositório
    $plugin_count = count($active_plugins);
    $themes_count = count($active_themes);

} else {
    // Se não houver dados do site, inicializar valores vazios
    $plugin_count = 0;
    $themes_count = 0;
}

// Contagem de itens arquivados
$archived_items_count = count($archived_items);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link href="https://fonts.googleapis.com/css2?family=Bricolage+Grotesque:opsz,wght@12..96,200..800&family=Inter:wght@100..900&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
</head>
<body>
    <div id="overlay" class="overlay"></div>
<div class="container">
    
<div class="menu">
    <span class="menu-close"><i class="fa-solid fa-xmark"></i></span>
    <div class="logo-div"><img src="<?php echo esc_url($logo_url); ?>" alt="Logo" id="wpgpl-logo" class="logo"/></div>
    
    <ul class="nav-list">
        <li>
            <a href="/wp-admin/admin.php?page=<?php echo $GLOBALS['wpgpl_plugin_slug'] . '-multisites'; ?>" class="nav-item <?php echo ($_GET['page'] == $GLOBALS['wpgpl_plugin_slug'] . '-multisites') ? 'active' : ''; ?>">
                <i class="fa-solid fa-arrow-left"></i>
                <span class="nav-text">Multisites</span>
            </a>
        </li>
        <div class="separator"></div>
        <h3 class="header-menu">EXPLORE</h3>
        <li>
            <a href="/wp-admin/admin.php?page=<?php echo $GLOBALS['wpgpl_plugin_slug']; ?>" class="nav-item <?php echo ($_GET['page'] == $GLOBALS['wpgpl_plugin_slug']) ? 'active' : ''; ?>">
                <i class="fa-solid fa-house"></i>
                <span class="nav-text">Dashboard</span>
                <?php
                if ($outdated_count > 0) {
                    echo '<span style="background-color: #23c55e; color: #fff; font-weight: 600; padding: 2px 8px; border-radius: 2px; margin-left:8px;">' . $outdated_count . '</span>';
                }
                ?>
            </a>
        </li>
        <!-- Mover "Histórico" e "Backup" logo abaixo de "Dashboard" -->
        <li>
            <a href="/wp-admin/admin.php?page=<?php echo $GLOBALS['wpgpl_plugin_slug'] . '-history'; ?>" class="nav-item <?php echo ($_GET['page'] == $GLOBALS['wpgpl_plugin_slug'] . '-history') ? 'active' : ''; ?>">
                <i class="fa-solid fa-list-ul"></i>
                <span class="nav-text">Histórico</span>
            </a>
        </li>
        <li>
            <a href="/wp-admin/admin.php?page=<?php echo $GLOBALS['wpgpl_plugin_slug'] . '-backup'; ?>" class="nav-item <?php echo ($_GET['page'] == $GLOBALS['wpgpl_plugin_slug'] . '-backup') ? 'active' : ''; ?>">
                <i class="fa-solid fa-cloud"></i>
                <span class="nav-text">Backup</span>
            </a>
        </li>
        <li>
            <a href="/wp-admin/admin.php?page=<?php echo esc_attr($GLOBALS['wpgpl_plugin_slug'] . '-domain'); ?>&site=<?php echo esc_attr($current_site_url); ?>" class="nav-item <?php echo ($_GET['page'] == $GLOBALS['wpgpl_plugin_slug'] . '-domain') ? 'active' : ''; ?>">
                <i class="fa-solid fa-laptop"></i>
                <span class="nav-text"><?php echo esc_html($site_name); ?></span>
            </a>
        </li>
        <?php
        // Simplificação do if para WPGPL Vault utilizando $plugin_name
        $plugin_name = $GLOBALS['wpgpl_plugin_name'];
        if ($plugin_name === 'WPGPL Vault') {
            ?>
            <div class="separator"></div>
            <h3 class="header-menu">CONFIGURAÇÕES</h3>
            <li>
                <a href="/wp-admin/admin.php?page=<?php echo $GLOBALS['wpgpl_plugin_slug'] . '-activation'; ?>" class="nav-item <?php echo ($_GET['page'] == $GLOBALS['wpgpl_plugin_slug'] . '-activation') ? 'active' : ''; ?>">
                    <i class="fa-solid fa-key"></i>
                    <span class="nav-text">Ativação de Licença</span>
                </a>
            </li>
            <li>
                <a href="https://wpgpl.com.br/changelog" class="nav-item" target="_blank">
                    <i class="fa-solid fa-repeat"></i>
                    <span class="nav-text">Atualizações</span>
                </a>
            </li>
            <li>
                <a href="https://stats.uptimerobot.com/UgJ47zF9b0" class="nav-item" target="_blank">
                    <i class="fa-solid fa-wifi"></i>
                    <span class="nav-text">Status da API</span>
                </a>
            </li>
            <li>
                <a href="https://api.whatsapp.com/send?phone=5561995940410" class="nav-item" target="_blank">
                    <i class="fa-solid fa-circle-question"></i>
                    <span class="nav-text">Precisa de Ajuda?</span>
                </a>
            </li>
            <?php
        }
        ?>
        <?php
        // Verificar se a licença não está ativa para exibir o item "Seja Unlimited" utilizando $wpgpl_uuid
        $wpgpl_uuid = $GLOBALS['wpgpl_uuid'];
        if (empty($wpgpl_uuid)) {
            ?>
            <li>
                <a href="https://wpgpl.com.br/pricing" class="nav-unlimited <?php echo ($_SERVER['REQUEST_URI'] == '/wp-admin/admin.php?page=wpgpl-pricing') ? 'active' : ''; ?>" target="_blank">
                    <i class="fa-solid fa-infinity"></i>
                    <span class="nav-text">Seja Unlimited</span>
                </a>
            </li>
            <?php
        }
        ?>
        <div class="separator"></div>
        <h3 class="header-menu"><?php echo strtoupper($GLOBALS['wpgpl_plugin_name']); ?> - VERSÃO: <?php echo strtoupper(WPGPL_VERSION); ?></h3>
    </ul>
</div>

<div class="wrap">
    <div class="header-title" style="display: flex; align-items: center; justify-content: space-between;">
        <span id="menu-toggle" class="menu-toggle">
    <i class="fa-solid fa-bars"></i>
</span>
   <h2 class="section-title">Dashboard</h2>
    <div class="theme-selection">
    <select id="wpgpl-theme-color" class="select-theme">
        <option value="1" <?php echo $selectedLight; ?>>Claro</option>
        <option value="0" <?php echo $selectedDark; ?>>Escuro</option>
        <option value="system" id="system-theme-option" <?php echo $selectedSystem; ?>>Sistema</option>
    </select>
</div>
</div>
<div class="separator"></div>
<hr class="wp-header-end">
<h2 class="section-title">
    <?php echo esc_html($site_name); ?> (<?php echo esc_html($current_site_url); ?>)
    <button id="delete-ip-btn" class="button" data-domain="<?php echo esc_attr($current_site_url); ?>"><i class="fa-solid fa-arrow-right-from-bracket"></i> Desconectar</button></h2>

<?php
// Obtendo o próximo agendamento para 'wpgpl_vault_automatic_updates' usando Action Scheduler
    $next_scheduled_time = as_next_scheduled_action('wpgpl_vault_multisite_automatic_updates', array($current_site_url, 'plugin', 0), 'wpgpl_vault');
    $time_remaining = $next_scheduled_time ? ($next_scheduled_time - time()) : 0; // Calcula o tempo restante em segundos
?>

<?php if (!empty($wpgpl_uuid)) :
    $total_cron_enabled = intval($plugin_cron_enabled) + intval($theme_cron_enabled);
    
    if ($total_cron_enabled > 0) : 
        if ($time_remaining > 0) : ?>
            <p class="description_1">
                Em <span id="cron-job-timer" data-time-remaining="<?php echo $time_remaining; ?>"></span>, as atualizações automáticas serão executadas.
            </p>
        <?php elseif (isset($backup_enabled) && $backup_enabled == 1) : ?>
            <p class="description_1">A atualização automática está ativada para ser realizada após o backup completo.</p>
        <?php else : ?>
            <p class="description_1">Erro: Não foi possível encontrar nenhum horário para a próxima atualização automática.</p>
        <?php endif; ?>
    <?php else : ?>
        <p class="description_2">A atualização automática está desativada</p>
    <?php endif; ?>
        <form id="update-settings-form" class="update-settings-form">
            <?php wp_nonce_field('wpgpl_vault_nonce', 'wpgpl_vault_nonce_field'); ?>
            <div class="form-group">
                <label for="plugin_cron_enabled">Atualização Automática de Plugins</label>
                <label class="switch">
                    <input type="checkbox" data-type="global" data-item-name="auto_update_plugins" id="plugin_cron_enabled" class="auto-update-plugin-cron" name="wpgpl_vault_plugin_cron_enabled" value="1" <?php checked(1, $plugin_cron_enabled, true); ?> data-enabled="<?php echo $plugin_cron_enabled ? '1' : '0'; ?>" />
                    <span class="slider"></span>
                </label>
            </div>
            <div class="form-group">
                <label for="theme_cron_enabled">Atualização Automática de Temas</label>
                <label class="switch">
                    <input type="checkbox" data-type="global" data-item-name="auto_update_themes" id="theme_cron_enabled" class="auto-update-theme-cron" name="wpgpl_vault_theme_cron_enabled" value="1" <?php checked(1, $theme_cron_enabled, true); ?> data-enabled="<?php echo $theme_cron_enabled ? '1' : '0'; ?>" />
                    <span class="slider"></span>
                </label>
            </div>
            <div class="form-group">
                <label for="backup_enabled">Integração Plugins de Backup</label>
                <label class="switch">
                    <input type="checkbox" id="backup_enabled" class="backup_enabled" name="wpgpl_vault_backup_enabled" value="1" <?php checked(1, $backup_enabled, true); ?> data-enabled="<?php echo $backup_enabled ? '1' : '0'; ?>" />
                    <span class="slider"></span>
                </label>
            </div>
        </form>
    <?php else : ?>
        <p class="description_2">Por favor, ative a licença para utilizar o plugin</p>
    <?php endif; ?>

<div class="tabs">
    <div class="tab-buttons">
        <button class="tab-button active-tab">
            <i class="fas fa-plug"></i> Plugins (<?php echo $plugin_count; ?>)
        </button>
        <button class="tab-button">
            <i class="fas fa-paint-brush"></i> Temas (<?php echo $themes_count; ?>)
        </button>
        <?php if (!empty($archived_items)) : ?>
            <button class="tab-button">
                <i class="fas fa-archive"></i> Arquivados (<?php echo $archived_items_count; ?>)
            </button>
        <?php endif; ?>
    </div>
</div>

<div class="bulk-actions">
    <select id="bulk-action-selector-top">
        <option value="-1">Ações em Massa</option>
        <option value="activate-auto-update">Ativar Atualização Automática</option>
        <option value="disable-auto-update">Desativar Atualização Automática</option>
        <option value="verify-update">Verificar Atualização</option>
    </select>
    <button id="doaction" class="button action">Aplicar</button>
</div>

<div class="tab-content">
    <div class="table-container">
        <table class="wp-list-table widefat fixed striped plugins-table">
            <thead>
                <tr>
                    <th><input type="checkbox" id="select-all-plugins"></th>
                    <?php if (!empty($wpgpl_uuid)) : ?>
                        <th>Atualização Automática</th>
                    <?php endif; ?>
                    <th>Nome</th>
                    <th>Versão</th>
                    <th>Verificar</th>
                    <th>Versão Disponível</th>
                    <th>Instalação Manual</th>
                    <th>Status</th>
                    <th>VirusTotal Report</th>
                    <th>Versões Anteriores</th>
                    <th>Suporte</th>
                    <?php if (!empty($wpgpl_uuid)) : ?>
                        <th>Arquivar</th> <!-- Nova coluna -->
                    <?php endif; ?>
                </tr>
            </thead>
            <tbody>
                <?php
                $show_error_message = false;
                if (isset($plugins_api_result['error'])) {
                    $show_error_message = true;
                } else {
                    // Criaremos um array para mapear os plugins existentes
                    $plugins_status = [];
                    foreach ($plugins_api_result as $item) {
                        $plugins_status[$item['name']] = $item['exists'];
                    }
                }

                if ($show_error_message === true) {
                    echo '<tr><td colspan="11" style="text-align:center;">Não foi encontrado nenhum plugin</td></tr>';
                } else {
                    
                $plugin_found = false;

                foreach ($site_plugins as $plugin) {
                    $plugin_name = isset($plugin['name']) ? $plugin['name'] : '';
                    $plugin_version = isset($plugin['version']) ? $plugin['version'] : '';
                    $auto_update = isset($plugin['auto_update']) && $plugin['auto_update'] ? 1 : 0;
                    
                    if (isset($plugin['archived']) && $plugin['archived']) {
                        continue;
                    }

                    // Verifique se o nome do plugin é "WPGPL Vault" e altere para $wpgpl_vault_name
                    $display_name = $plugin_name;
                    if ($plugin_name === 'WPGPL Vault') {
                        $display_name = $wpgpl_vault_name;
                    }

                    // Verifique se o plugin está arquivado
                    $is_archived = false;
                    foreach ($archived_items as $item) {
                        if ($item['name'] === $display_name && $item['type'] === 'WordPress Plugins') {
                            $is_archived = true;
                            break;
                        }
                    }

                    if ($is_archived) {
                        continue; // Pule os plugins arquivados
                    }
                    
                    // Verifique se o plugin está no repositório (com base no retorno da API)
                    if (isset($plugins_status[$plugin_name]) && !$plugins_status[$plugin_name]) {
                        continue; // Pule os plugins que não estão no seu repositório
                    }

                    $plugin_found = true;

                    // Inicialize variáveis de exibição
                    $api_version = '';
                    $status = '';
                    $download_button = '';

                    // Verifique se este plugin está nos itens desatualizados
                    foreach ($outdated_items as $item) {
                        if ($item['name'] === $plugin_name) {
                            $api_version = '<span style="background-color: #23c55e; color: #fff; font-weight: 600; padding: 4px 6px; border-radius: 4px;">' . esc_html($item['version']) . '</span>';
                            $status = '<span style="background-color: #e30047; color: #fff; font-weight: 600; padding: 4px 6px; border-radius: 4px;">Desatualizado</span>';
                            $download_button = '<button class="wpgpl-vault-download button" data-type="plugin" data-real-name="' . esc_attr($plugin_name) . '"><i class="fas fa-download"></i>Download e Instalar</button>';
                            break;
                        }
                    }

                    echo '<tr>';
                    echo '<td><input type="checkbox" id="plugin-select" class="plugin-select" data-real-name="' . esc_attr($plugin_name) . '" data-plugin="' . esc_attr($plugin_name) . '"></td>';
                    if (!empty($wpgpl_uuid)) {
                        echo '<td><label class="switch">
        <input type="checkbox" data-type="plugin" data-domain="<?php echo esc_attr($current_site_url); ?>" data-item-name="' . esc_attr($plugin_name) . '" class="auto-update-plugin" data-plugin="' . esc_attr($plugin_name) . '" data-enabled="' . ($auto_update ? '1' : '0') . '" ' . ($auto_update ? 'checked' : '') . ' />
        <span class="slider ' . ($auto_update ? 'ajax-success' : '') . '"></span>
      </label></td>';
                    }
                    echo '<td>' . esc_html($display_name) . '</td>';
                    echo '<td class="wpgpl-vault-current-version"><span class="version-text">' . esc_html($plugin_version) . '</span></td>';
                    echo '<td>
                            <button class="wpgpl-vault-check button" data-type="plugin" data-name="' . esc_attr($display_name) . '" data-real-name="' . esc_attr($plugin_name) . '" ' . (empty($wpgpl_uuid) ? 'disabled' : '') . '>
                                <i class="fas fa-search"></i> Verificar
                            </button>
                          </td>';
                    echo '<td class="wpgpl-vault-api-version">' . $api_version . '</td>';
                    echo '<td class="wpgpl-vault-api-download">' . $download_button . '</td>';
                    echo '<td class="wpgpl-vault-status">' . $status . '</td>';
                    echo '<td class="wpgpl-vault-virus-total"></td>';
                    echo '<td class="wpgpl-vault-api-old-download"></td>';
                    echo '<td class="wpgpl-vault-support-column">
                            <button class="wpgpl-vault-support button" data-real-name="' . esc_attr($plugin_name) . '" data-name="' . esc_attr($display_name) . '" data-version="' . esc_attr($plugin_version) . '" data-error="precisa ser atualizado" ' . (empty($wpgpl_uuid) ? 'disabled' : '') . '>
                                <i class="fas fa-exclamation-circle"></i> Precisa ser Atualizado
                            </button>
                            <button class="wpgpl-vault-support button" data-real-name="' . esc_attr($plugin_name) . '" data-name="' . esc_attr($display_name) . '" data-version="' . esc_attr($plugin_version) . '" data-error="erros de atualização" ' . (empty($wpgpl_uuid) ? 'disabled' : '') . '>
                                        <i class="fas fa-bug"></i> Arquivo com Erro
                                    </button>
                          </td>';
                    if (!empty($wpgpl_uuid)) {
                        echo '<td class="archive-item-center" data-domain="<?php echo esc_attr($current_site_url); ?>"><a href="javascript:void(0);" class="archive-item x-text" data-plugin="' . esc_attr($plugin_name) . '" data-real-name="' . esc_attr($plugin_name) . '" data-name="' . esc_attr($display_name) . '" data-type="plugin" data-nonce="' . wp_create_nonce('wpgpl_vault_nonce_field') . '">X</a></td>';
                    }
                    echo '</tr>';
                }

                if (!$plugin_found) {
                    echo '<tr><td colspan="9" style="text-align:center;">Não foi encontrado nenhum plugin</td></tr>';
                }}
                ?>
            </tbody>
        </table>
    </div>
</div>

<div class="tab-content">
    <div class="table-container">
        <table class="wp-list-table widefat fixed striped theme-table">
            <thead>
                <tr>
                    <th><input type="checkbox" id="select-all-themes"></th>
                    <?php if (!empty($wpgpl_uuid)) : ?>
                        <th>Atualização Automática</th>
                    <?php endif; ?>
                    <th>Nome</th>
                    <th>Versão</th>
                    <th>Verificar</th>
                    <th>Versão Disponível</th>
                    <th>Instalação Manual</th>
                    <th>Status</th>
                    <th>VirusTotal Report</th>
                    <th>Versões Anteriores</th>
                    <th>Suporte</th>
                    <?php if (!empty($wpgpl_uuid)) : ?>
                        <th>Arquivar</th> <!-- Nova coluna -->
                    <?php endif; ?>
                </tr>
            </thead>
            <tbody>
                <?php
                $show_error_message = false;
                if (isset($themes_api_result['error'])) {
                    $show_error_message = true;
                } else {
                    // Criaremos um array para mapear os temas existentes
                    $themes_status = [];
                    foreach ($themes_api_result as $item) {
                        $themes_status[$item['name']] = $item['exists'];
                    }
                }

                if ($show_error_message === true) {
                    echo '<tr><td colspan="11" style="text-align:center;">Não foi encontrado nenhum tema</td></tr>';
                } else {
                
                $theme_found = false;

                foreach ($site_themes as $theme) {
                    $theme_name = isset($theme['name']) ? $theme['name'] : '';
                    $theme_version = isset($theme['version']) ? $theme['version'] : '';
                    $auto_update = isset($theme['auto_update']) && $theme['auto_update'] ? 1 : 0;
                    
                    if (isset($theme['archived']) && $theme['archived']) {
                        continue;
                    }

                    // Verifique se o tema está arquivado
                    $is_archived = false;
                    foreach ($archived_items as $item) {
                        if ($item['name'] === $theme_name && $item['type'] === 'WordPress Themes') {
                            $is_archived = true;
                            break;
                        }
                    }

                    if ($is_archived) {
                        continue; // Pule os temas arquivados
                    }
                    
                    // Verifique se o tema está no repositório (com base no retorno da API)
                    if (isset($themes_status[$theme_name]) && !$themes_status[$theme_name]) {
                        continue; // Pule os temas que não estão no seu repositório
                    }

                    $theme_found = true;

                    // Inicialize variáveis de exibição
                    $api_version = '';
                    $status = '';
                    $download_button = '';

                    // Verifique se este tema está nos itens desatualizados
                    foreach ($outdated_items as $item) {
                        if ($item['name'] === $theme_name) {
                            $api_version = '<span style="background-color: #23c55e; color: #fff; font-weight: 600; padding: 4px 6px; border-radius: 4px;">' . esc_html($item['version']) . '</span>';
                            $status = '<span style="background-color: #e30047; color: #fff; font-weight: 600; padding: 4px 6px; border-radius: 4px;">Desatualizado</span>';
                            $download_button = '<button class="wpgpl-vault-download button" data-type="theme" data-real-name="' . esc_attr($theme_name) . '"><i class="fas fa-download"></i>Download e Instalar</button>';
                            break;
                        }
                    }

                    echo '<tr>';
                    echo '<td><input type="checkbox" id="theme-select" class="theme-select" data-theme="' . esc_attr($theme_name) . '"></td>';
                    if (!empty($wpgpl_uuid)) {
                        echo '<td><label class="switch">
        <input type="checkbox" data-type="theme" data-domain="<?php echo esc_attr($current_site_url); ?>" data-item-name="' . esc_attr($theme_name) . '" class="auto-update-theme" data-theme="' . esc_attr($theme_name) . '" data-enabled="' . ($auto_update ? '1' : '0') . '" ' . ($auto_update ? 'checked' : '') . ' />
        <span class="slider ' . ($auto_update ? 'ajax-success' : '') . '"></span>
      </label></td>';
                    }
                    echo '<td>' . esc_html($theme_name) . '</td>';
                    echo '<td class="wpgpl-vault-current-version"><span class="version-text">' . esc_html($theme_version) . '</span></td>';
                    echo '<td>
                            <button class="wpgpl-vault-check button" data-type="theme" data-real-name="' . esc_attr($theme_name) . '" ' . (empty($wpgpl_uuid) ? 'disabled' : '') . '>
                                <i class="fas fa-search"></i> Verificar
                            </button>
                          </td>';
                    echo '<td class="wpgpl-vault-api-version">' . $api_version . '</td>';
                    echo '<td class="wpgpl-vault-api-download">' . $download_button . '</td>';
                    echo '<td class="wpgpl-vault-status">' . $status . '</td>';
                    echo '<td class="wpgpl-vault-virus-total"></td>';
                    echo '<td class="wpgpl-vault-api-old-download"></td>';
                    echo '<td class="wpgpl-vault-support-column">
                            <button class="wpgpl-vault-support button" data-real-name="' . esc_attr($theme_name) . '" data-version="' . esc_attr($theme_version) . '" data-error="precisa ser atualizado" ' . (empty($wpgpl_uuid) ? 'disabled' : '') . '>
                                <i class="fas fa-exclamation-circle"></i> Precisa ser Atualizado
                            </button>
                            <button class="wpgpl-vault-support button" data-real-name="' . esc_attr($theme_name) . '" data-version="' . esc_attr($theme_version) . '" data-error="erros de atualização" ' . (empty($wpgpl_uuid) ? 'disabled' : '') . '>
                                        <i class="fas fa-bug"></i> Arquivo com Erro
                                    </button>
                          </td>';
                    if (!empty($wpgpl_uuid)) {
                        echo '<td class="archive-item-center" data-domain="<?php echo esc_attr($current_site_url); ?>"><a href="javascript:void(0);" class="archive-item x-text" data-name="' . esc_attr($theme_name) . '" data-type="theme" data-nonce="' . wp_create_nonce('wpgpl_vault_nonce_field') . '">X</a></td>';
                    }
                    echo '</tr>';
                }

                if (!$theme_found) {
                    echo '<tr><td colspan="9" style="text-align:center;">Não foi encontrado nenhum tema</td></tr>';
                }}
                ?>
            </tbody>
        </table>
    </div>
</div>
<div class="tab-content">
    <div class="table-container">
        <table class="wp-list-table widefat fixed striped archived-table">
            <thead>
                <tr>
                    <th>Nome</th>
                    <th>Tipo</th>
                    <?php if (!empty($wpgpl_uuid)) : ?>
                        <th>Desarquivar</th>
                    <?php endif; ?>
                </tr>
            </thead>
            <tbody>
                <?php if (!empty($archived_items)) : ?>
                    <?php foreach ($archived_items as $item) : ?>
                        <tr>
                            <td>
                                <?php
                                $item_name = ($item['name'] === 'WPGPL Vault') ? $wpgpl_vault_name : $item['name'];
                                echo esc_html($item_name);
                                ?>
                            </td>
                            <td>
                                <?php
                                $item_type = '';
                                $data_type = '';
                                
                                if (in_array($item, $site_plugins)) {
                                    $item_type = 'WordPress Plugins';
                                    $data_type = 'plugin'; // Define data-type como 'plugin' para plugins
                                } elseif (in_array($item, $site_themes)) {
                                    $item_type = 'WordPress Themes';
                                    $data_type = 'theme'; // Define data-type como 'theme' para temas
                                } else {
                                    $item_type = 'Desconhecido';
                                }

                                echo esc_html($item_type);
                                ?>
                            </td>
                            <?php if (!empty($wpgpl_uuid)) : ?>
                                <td>
                                    <button class="unarchive-item button" 
                                            data-nonce="<?php echo wp_create_nonce('wpgpl_vault_nonce_field'); ?>" 
                                            data-domain="<?php echo esc_attr($current_site_url); ?>" 
                                            data-name="<?php echo esc_attr($item['name']); ?>"
                                            data-type="<?php echo esc_attr($data_type); ?>"> <!-- data-type ajustado -->
                                        <i class="fas fa-undo-alt"></i> Desarquivar
                                    </button>
                                </td>
                            <?php endif; ?>
                        </tr>
                    <?php endforeach; ?>
                <?php else : ?>
                    <tr><td colspan="3" style="text-align:center;">Nenhum item arquivado encontrado</td></tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
</div>



</body>
</html>