<?php
// Certifique-se de que as variáveis globais foram definidas
wpgpl_set_global_theme_variables(); // Chame esta função no início do script ou em um hook apropriado

$logo_url = $GLOBALS['wpgpl_plugin_slogan_url'];

global $wpgpl_theme_color;

// Determinar a seleção baseada no valor retornado
$selectedLight = ($wpgpl_theme_color === '1') ? 'selected' : '';
$selectedDark = ($wpgpl_theme_color === '0') ? 'selected' : '';
$selectedSystem = (!in_array($wpgpl_theme_color, ['0', '1'])) ? 'selected' : '';

// Obter os itens desatualizados armazenados
$outdated_items = wpgpl_vault_get_option('wpgpl_vault_items_outdate', []);

// Certifique-se de que $outdated_items é um array
if (!is_array($outdated_items)) {
    $outdated_items = [];
}
// Contar o número de itens no array
$outdated_count = is_array($outdated_items) ? count($outdated_items) : 0;

// Obter a lista de plugins de backup ativos
$active_plugins = wpgpl_get_backups_active();

// Lista de todos os plugins de backup que estão sendo monitorados
$backup_plugins = [
    'all-in-one-wp-migration/all-in-one-wp-migration.php' => 'All in One WP Migration',
    'updraftplus/updraftplus.php' => 'UpdraftPlus',
    'duplicator-pro/duplicator-pro.php' => 'Duplicator Pro'
];

// Verificar quais plugins estão instalados, mas não ativos
$installed_plugins = [];
foreach ($backup_plugins as $slug => $name) {
    // Caminho do plugin
    $plugin_file = WP_PLUGIN_DIR . '/' . $slug;

    // Verificar se o plugin está instalado e não está ativo
    if (file_exists($plugin_file) && !in_array($name, $active_plugins)) {
        $installed_plugins[] = $name;
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link href="https://fonts.googleapis.com/css2?family=Bricolage+Grotesque:opsz,wght@12..96,200..800&family=Inter:wght@100..900&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
</head>
<body>
<div id="overlay" class="overlay"></div>
<div class="container">
    
<div class="menu">
    <span class="menu-close"><i class="fa-solid fa-xmark"></i></span>
    <div class="logo-div"><img src="<?php echo esc_url($logo_url); ?>" alt="Logo" id="wpgpl-logo" class="logo"/></div>
    
    <ul class="nav-list">
        <li>
            <a href="/wp-admin/" class="nav-item <?php echo (strpos($_SERVER['REQUEST_URI'], '/wp-admin/') !== false && !strpos($_SERVER['REQUEST_URI'], 'admin.php?page=')) ? 'active' : ''; ?>">
                <i class="fa-solid fa-arrow-left"></i>
                <span class="nav-text">WP Dashboard</span>
            </a>
        </li>
        <div class="separator"></div>
        <h3 class="header-menu">EXPLORE</h3>
        <li>
            <a href="/wp-admin/admin.php?page=<?php echo $GLOBALS['wpgpl_plugin_slug']; ?>" class="nav-item <?php echo ($_GET['page'] == $GLOBALS['wpgpl_plugin_slug']) ? 'active' : ''; ?>">
                <i class="fa-solid fa-house"></i>
                <span class="nav-text">Dashboard</span>
                <?php
                if ($outdated_count > 0) {
                    echo '<span style="background-color: #23c55e; color: #fff; font-weight: 600; padding: 2px 8px; border-radius: 2px; margin-left:8px;">' . $outdated_count . '</span>';
                }
                ?>
            </a>
        </li>
        <!-- Mover "Histórico" e "Backup" logo abaixo de "Dashboard" -->
        <li>
            <a href="/wp-admin/admin.php?page=<?php echo $GLOBALS['wpgpl_plugin_slug'] . '-history'; ?>" class="nav-item <?php echo ($_GET['page'] == $GLOBALS['wpgpl_plugin_slug'] . '-history') ? 'active' : ''; ?>">
                <i class="fa-solid fa-list-ul"></i>
                <span class="nav-text">Histórico</span>
            </a>
        </li>
        <li>
            <a href="/wp-admin/admin.php?page=<?php echo $GLOBALS['wpgpl_plugin_slug'] . '-backup'; ?>" class="nav-item <?php echo ($_GET['page'] == $GLOBALS['wpgpl_plugin_slug'] . '-backup') ? 'active' : ''; ?>">
                <i class="fa-solid fa-cloud"></i>
                <span class="nav-text">Backup</span>
            </a>
        </li>
        <li>
            <a href="/wp-admin/admin.php?page=<?php echo $GLOBALS['wpgpl_plugin_slug'] . '-multisites'; ?>" class="nav-item <?php echo ($_GET['page'] == $GLOBALS['wpgpl_plugin_slug'] . '-multisites') ? 'active' : ''; ?>">
                <i class="fa-solid fa-globe"></i>
                <span class="nav-text">Multisites</span>
            </a>
        </li>
        <?php
        // Simplificação do if para WPGPL Vault utilizando $plugin_name
        $plugin_name = $GLOBALS['wpgpl_plugin_name'];
        if ($plugin_name === 'WPGPL Vault') {
            ?>
            <div class="separator"></div>
            <h3 class="header-menu">CONFIGURAÇÕES</h3>
            <li>
                <a href="/wp-admin/admin.php?page=<?php echo $GLOBALS['wpgpl_plugin_slug'] . '-activation'; ?>" class="nav-item <?php echo ($_GET['page'] == $GLOBALS['wpgpl_plugin_slug'] . '-activation') ? 'active' : ''; ?>">
                    <i class="fa-solid fa-key"></i>
                    <span class="nav-text">Ativação de Licença</span>
                </a>
            </li>
            <li>
                <a href="https://wpgpl.com.br/changelog" class="nav-item" target="_blank">
                    <i class="fa-solid fa-repeat"></i>
                    <span class="nav-text">Atualizações</span>
                </a>
            </li>
            <li>
                <a href="https://stats.uptimerobot.com/UgJ47zF9b0" class="nav-item" target="_blank">
                    <i class="fa-solid fa-wifi"></i>
                    <span class="nav-text">Status da API</span>
                </a>
            </li>
            <li>
                <a href="https://api.whatsapp.com/send?phone=5561995940410" class="nav-item" target="_blank">
                    <i class="fa-solid fa-circle-question"></i>
                    <span class="nav-text">Precisa de Ajuda?</span>
                </a>
            </li>
            <?php
        }
        ?>
        <?php
        // Verificar se a licença não está ativa para exibir o item "Seja Unlimited" utilizando $wpgpl_uuid
        $wpgpl_uuid = $GLOBALS['wpgpl_uuid'];
        if (empty($wpgpl_uuid)) {
            ?>
            <li>
                <a href="https://wpgpl.com.br/pricing" class="nav-unlimited <?php echo ($_SERVER['REQUEST_URI'] == '/wp-admin/admin.php?page=wpgpl-pricing') ? 'active' : ''; ?>" target="_blank">
                    <i class="fa-solid fa-infinity"></i>
                    <span class="nav-text">Seja Unlimited</span>
                </a>
            </li>
            <?php
        }
        ?>
        <div class="separator"></div>
        <h3 class="header-menu"><?php echo strtoupper($GLOBALS['wpgpl_plugin_name']); ?> - VERSÃO: <?php echo strtoupper(WPGPL_VERSION); ?></h3>
    </ul>
</div>

<div class="wrap">
    <div class="header-title" style="display: flex; align-items: center; justify-content: space-between;">
        <span id="menu-toggle" class="menu-toggle">
    <i class="fa-solid fa-bars"></i>
</span>
    <h1 class="main-title">Backup</h1>
    <div class="theme-selection">
    <select id="wpgpl-theme-color" class="select-theme">
        <option value="1" <?php echo $selectedLight; ?>>Claro</option>
        <option value="0" <?php echo $selectedDark; ?>>Escuro</option>
        <option value="system" id="system-theme-option" <?php echo $selectedSystem; ?>>Sistema</option>
    </select>
</div>
</div>
<div class="separator"></div>
<hr class="wp-header-end">
<?php
$wpgpl_uuid = $GLOBALS['wpgpl_uuid'];

if (empty($wpgpl_uuid)): ?>
    <p class="description_2">Por favor, ative a licença para utilizar o plugin</p>
<?php else: ?>
    <form id="update-settings-form" class="update-settings-form">
        <?php wp_nonce_field('wpgpl_vault_nonce', 'wpgpl_vault_nonce_field'); ?>
        <div class="form-group">
            <label for="automatic-update-switch" class="automatic-update-switch">Integração Plugins de Backup</label>
            <label class="switch">
                <input type="checkbox" id="automatic-update-switch" class="auto-update-switch" <?php checked($GLOBALS['wpgpl_backup_integration'], 1); ?> />
                <span class="slider"></span>
            </label>
        </div>
    </form>

    <?php if ($GLOBALS['wpgpl_backup_integration'] == 0): ?>
        <p class="description_2">A integração com os plugins de backup está desativada. As atualizações automáticas serão realizadas sem backup de 12 em 12 horas.</p>
    <?php else: ?>
        <p class="description_1">Se você deseja integrar o nosso plugin com algum outro plugin de backup, entre em contato com nosso suporte.</p>
        
        <?php if (!empty($active_plugins)): ?>
            <p>Os seguintes plugins de backup estão ativos:</p>
            <ul class="active-backups">
                <?php foreach ($active_plugins as $plugin_name): ?>
                    <li class="backup-name"><?php echo $plugin_name; ?></li>
                <?php endforeach; ?>
            </ul>
            <p class="description_2">A atualização automática sempre será realizada após um backup completo (incluindo Arquivos e Banco de Dados) de um dos plugins listados acima. Por exemplo, se você configurar o backup para ocorrer diariamente, então as atualizações automáticas também serão diárias.</p>
        <?php elseif (!empty($installed_plugins)): ?>
            <p>A integração de backup está disponível para os plugins abaixo, mas eles não estão ativados:</p>
            <ul class="active-backups">
                <?php foreach ($installed_plugins as $plugin_name): ?>
                    <li class="backup-name"><?php echo $plugin_name; ?></li>
                <?php endforeach; ?>
            </ul>
            <p class="description_2">Para utilizar as funcionalidades de backup, por favor ative um dos plugins acima.</p>
        <?php else: ?>
            <p>Você precisa instalar um dos seguintes plugins para a integração funcionar corretamente:</p>
            <ul class="active-backups">
                <?php foreach ($backup_plugins as $slug => $name): ?>
                    <li class="backup-name"><?php echo $name; ?></li>
                <?php endforeach; ?>
            </ul>
            <p class="description_2">Esses plugins oferecem funcionalidades de backup que podem ser integradas com o WPGPL Vault. Por favor, instale e ative um dos plugins listados para começar a utilizar os recursos de backup.</p>
        <?php endif; ?>
    <?php endif; ?>
<?php endif; ?>

</body>
</html>