<?php
/*
 * Plugin Name: WPGPL Vault
 * Plugin URI: https://wpgpl.com.br/
 * Description: Proteja e gerencie seu site WordPress com o WPGPL Vault. Faça backups automáticos, verifique arquivos com relatórios do VirusTotal, instale atualizações manualmente, tenha controle total com rollback e histórico de mudanças.
 * Version: 4.20.1
 * Requires at Least: 6.0
 * Requires PHP: 7.4
 * Author: Ian Chamba
 * Author URI: https://wpgpl.com.br/
 * License: GPL-2.0+
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 **/

if (!defined('ABSPATH')) {
    exit;
}

if (!defined('WPGPL_PLUGIN_PATH')) {
    define('WPGPL_PLUGIN_PATH', plugin_dir_path(__FILE__));
}

if (!defined('WPGPL_PLUGIN_URL')) {
    define('WPGPL_PLUGIN_URL', plugin_dir_url(__FILE__));
}

if (!defined('WPGPL_PLUGIN_BASENAME')) {
    define('WPGPL_PLUGIN_BASENAME', plugin_basename(__FILE__));
}

require_once WPGPL_PLUGIN_PATH . 'integrations/woocommerce/action-scheduler/action-scheduler.php';

require_once WPGPL_PLUGIN_PATH . 'includes/Admin/Notices.php';
require_once WPGPL_PLUGIN_PATH . 'includes/Admin/Pages.php';
require_once WPGPL_PLUGIN_PATH . 'includes/Ajax/AjaxFunctions.php';
require_once WPGPL_PLUGIN_PATH . 'includes/Backups/BackupFunctions.php';
require_once WPGPL_PLUGIN_PATH . 'includes/CheckUpdates/CheckUpdates.php';
require_once WPGPL_PLUGIN_PATH . 'includes/Constants/Constants.php';
require_once WPGPL_PLUGIN_PATH . 'includes/History/CleanHistory.php';
require_once WPGPL_PLUGIN_PATH . 'includes/History/History.php';
require_once WPGPL_PLUGIN_PATH . 'includes/Table/Table.php';
require_once WPGPL_PLUGIN_PATH . 'includes/Updates/ActionScheduler.php';
require_once WPGPL_PLUGIN_PATH . 'includes/Updates/License.php';
require_once WPGPL_PLUGIN_PATH . 'includes/Updates/Notices.php';
require_once WPGPL_PLUGIN_PATH . 'includes/Utils/ArchivedItems.php';
require_once WPGPL_PLUGIN_PATH . 'includes/Utils/AutoUpdate.php';
require_once WPGPL_PLUGIN_PATH . 'includes/Utils/Miscellaneous.php';
require_once WPGPL_PLUGIN_PATH . 'includes/Utils/Notices.php';
require_once WPGPL_PLUGIN_PATH . 'integrations/wpgpl-child/AjaxFunctions.php';
require_once WPGPL_PLUGIN_PATH . 'integrations/wpgpl-child/Api.php';
require_once WPGPL_PLUGIN_PATH . 'integrations/wpgpl-child/ActionScheduler.php';
require_once WPGPL_PLUGIN_PATH . 'integrations/wpgpl-child/Utils.php';

register_activation_hook(WPGPL_PLUGIN_PATH . 'wpgpl-vault.php', 'wpgpl_vault_create_table');

function wpgpl_vault_deactivate() {
    wpgpl_vault_delete_option('wpgpl_vault_license_key');
    wpgpl_vault_delete_option('wpgpl_vault_uuid');
    wpgpl_vault_delete_option('wpgpl_agency_name');
    wpgpl_vault_delete_option('wpgpl_agency_url');
    wpgpl_vault_delete_option('wpgpl_plugin_name');
    wpgpl_vault_delete_option('wpgpl_plugin_description');
    wpgpl_vault_delete_option('wpgpl_plugin_slogan_dark_url');
    wpgpl_vault_delete_option('wpgpl_plugin_slogan_light_url');
    wpgpl_vault_delete_option('wpgpl_plugin_icon_url');
    wpgpl_vault_delete_option('wpgpl_user_id');
    wpgpl_vault_delete_option('wpgpl_display_name');
    wpgpl_vault_delete_option('wpgpl_user_email');
    wpgpl_vault_delete_option('wpgpl_theme_color');
    wpgpl_vault_delete_option('wpgpl_vault_archived_items');
    wpgpl_vault_delete_option('wpgpl_vault_auto_update_plugins');
    wpgpl_vault_delete_option('wpgpl_vault_auto_update_themes');
    wpgpl_vault_delete_option('wpgpl_vault_backup_integration');
    wpgpl_vault_delete_option('wpgpl_vault_active_backup_plugins');
    
    $icon_path = WPGPL_PLUGIN_PATH . 'media/icon_whitelabel.svg';
    
    if (file_exists($icon_path)) {
        unlink($icon_path);
    }
}
register_deactivation_hook(WPGPL_PLUGIN_PATH . 'wpgpl-vault.php', 'wpgpl_vault_deactivate');

function wpgpl_vault_activate() {

    $start_time_daily = strtotime('tomorrow');

    if (!wp_next_scheduled('wpgpl_vault_check_license_cron_job')) {
        wp_schedule_event($start_time_daily, 'daily', 'wpgpl_vault_check_license_cron_job');
    }
    if (!wp_next_scheduled('wpgpl_vault_check_wpgpl_version')) {
        wp_schedule_event($start_time_daily, 'daily', 'wpgpl_vault_check_wpgpl_version');
    }
    if (!wp_next_scheduled('wpgpl_vault_daily_cleanup_event')) {
        wp_schedule_event($start_time_daily, 'daily', 'wpgpl_vault_daily_cleanup_event');
    }
}
register_activation_hook(WPGPL_PLUGIN_PATH . 'wpgpl-vault.php', 'wpgpl_vault_activate');

function wpgpl_vault_deactivate_cron() {
    $timestamp_license = wp_next_scheduled('wpgpl_vault_check_license_cron_job');
    wp_unschedule_event($timestamp_license, 'wpgpl_vault_check_license_cron_job');
    
    $timestamp_version = wp_next_scheduled('wpgpl_vault_daily_cleanup_event');
    wp_unschedule_event($timestamp_version, 'wpgpl_vault_daily_cleanup_event');
    
    $timestamp_version = wp_next_scheduled('wpgpl_vault_check_wpgpl_version');
    wp_unschedule_event($timestamp_version, 'wpgpl_vault_check_wpgpl_version');
}
register_deactivation_hook(WPGPL_PLUGIN_PATH . 'wpgpl-vault.php', 'wpgpl_vault_deactivate_cron');

function wpgpl_vault_verify_cron_jobs() {
    $crons = array(
        'wpgpl_vault_check_license_cron_job' => 'daily',
        'wpgpl_vault_check_wpgpl_version' => 'daily',
        'wpgpl_vault_daily_cleanup_event' => 'daily',
    );

    foreach ($crons as $hook => $recorrencia) {
        if (!wp_next_scheduled($hook)) {
            
            $start_time = strtotime('tomorrow');

            wp_schedule_event($start_time, $recorrencia, $hook);
            error_log("A tarefa cron '$hook' não estava ativa e foi agendada para começar às " . date('Y-m-d H:i:s', $start_time) . ".");
        }
    }
}
add_action('wp_loaded', 'wpgpl_vault_verify_cron_jobs');

function wpgpl_vault_schedule_updates() {
    // Verifica o valor da opção wpgpl_vault_backup_integration no banco de dados
    $automatic_update_enabled = wpgpl_vault_get_option('wpgpl_vault_backup_integration');

    // Verifica o valor das opções wpgpl_vault_theme_cron_enabled e wpgpl_vault_plugin_cron_enabled no banco de dados
    $theme_cron_enabled = wpgpl_vault_get_option('wpgpl_vault_theme_cron_enabled');
    $plugin_cron_enabled = wpgpl_vault_get_option('wpgpl_vault_plugin_cron_enabled');

    // Se o valor for null, vazio ou igual a 0, agendar a ação automática
    if ((is_null($automatic_update_enabled) || empty($automatic_update_enabled) || $automatic_update_enabled == 0) &&
        ($theme_cron_enabled || $plugin_cron_enabled)) {

        // Verifica se a ação já está agendada para evitar duplicações
        if (!as_next_scheduled_action('wpgpl_vault_automatic_updates', [], 'wpgpl_vault')) {
            // Agenda a ação para rodar a cada 12 horas usando ActionScheduler
            as_schedule_recurring_action(time() + 12 * HOUR_IN_SECONDS, 12 * HOUR_IN_SECONDS, 'wpgpl_vault_automatic_updates', [], 'wpgpl_vault');
            error_log('Ação automática agendada com sucesso');
        }

    } else {
        // Se o valor for diferente de null, vazio ou 0, ou ambos theme_cron_enabled e plugin_cron_enabled são false, desativar a ação se ela estiver agendada
        $timestamp = as_next_scheduled_action('wpgpl_vault_automatic_updates', [], 'wpgpl_vault');
        if ($timestamp) {
            // Remove a ação agendada usando ActionScheduler
            as_unschedule_action('wpgpl_vault_automatic_updates', [], 'wpgpl_vault');
            error_log('Ação automática desagendada');
        }
    }
}
register_activation_hook(WPGPL_PLUGIN_PATH . 'wpgpl-vault.php', 'wpgpl_vault_schedule_updates');
add_action('wpgpl_check_automatic_update', 'wpgpl_vault_schedule_updates');

function wpgpl_vault_schedule_multisite_updates() {
    // Obtém os dados dos multisites
    $multisites_data = wpgpl_vault_get_option('wpgpl_multisites_data', []);

    // Verifica se há pelo menos um domínio no banco de dados
    if (empty($multisites_data) || count($multisites_data) === 0) {
        error_log('Nenhum domínio encontrado em wpgpl_multisites_data. Desagendando todas as ações.');

        // Desagendar todas as ações se não houver domínios
        $scheduled_actions = as_get_scheduled_actions([
            'hook' => 'wpgpl_vault_multisite_automatic_updates',
            'status' => ActionScheduler_Store::STATUS_PENDING,
        ]);

        foreach ($scheduled_actions as $action) {
            as_unschedule_action('wpgpl_vault_multisite_automatic_updates', $action->get_args(), 'wpgpl_vault');
        }

        return; // Interrompe a função se não houver domínios
    }

    // Pega todos os domínios agendados no Action Scheduler
    $scheduled_actions = as_get_scheduled_actions([
        'hook' => 'wpgpl_vault_multisite_automatic_updates',
        'status' => ActionScheduler_Store::STATUS_PENDING,
    ]);

    // Verifica todos os agendamentos e remove aqueles que não estão mais no banco de dados
    foreach ($scheduled_actions as $action) {
        $scheduled_args = $action->get_args(); // Obtenha os argumentos corretamente usando get_args()
        $scheduled_domain = $scheduled_args[0] ?? null;

        // Se o domínio agendado não estiver mais no banco de dados, removemos o agendamento
        if ($scheduled_domain && !isset($multisites_data[$scheduled_domain])) {
            as_unschedule_action('wpgpl_vault_multisite_automatic_updates', $scheduled_args, 'wpgpl_vault');
            error_log("Ação automática desagendada para o domínio $scheduled_domain que não está mais no banco de dados.");
        }
    }

    // Variável para verificar se todos os domínios devem ser desagendados
    $all_desagendado = true;

    // Agendar ou desagendar individualmente por domínio
    foreach ($multisites_data as $domain => $data) {
        $backup_active = isset($data['site_info']['backup_active']) ? $data['site_info']['backup_active'] : false;
        $auto_update_plugins = isset($data['site_info']['auto_update_plugins']) ? $data['site_info']['auto_update_plugins'] : false;
        $auto_update_themes = isset($data['site_info']['auto_update_themes']) ? $data['site_info']['auto_update_themes'] : false;

        // Se ambos os auto updates estão desativados, desagenda a ação para o domínio
        if (!$auto_update_plugins && !$auto_update_themes) {
            $timestamp = as_next_scheduled_action('wpgpl_vault_multisite_automatic_updates', [$domain, 'plugin', 0], 'wpgpl_vault');
            if ($timestamp) {
                as_unschedule_action('wpgpl_vault_multisite_automatic_updates', [$domain, 'plugin', 0], 'wpgpl_vault');
                error_log("Ação automática desagendada para o domínio $domain porque os auto updates estão desativados.");
            }
            continue; // Passa para o próximo domínio, pois não precisa agendar
        }

        // Se pelo menos um auto update estiver ativo e backup_active for false, agende a ação
        if (!$backup_active && ($auto_update_plugins || $auto_update_themes)) {
            $all_desagendado = false; // Encontramos um domínio que deve ser agendado

            // Verifica se a ação já está agendada para o domínio específico
            if (!as_next_scheduled_action('wpgpl_vault_multisite_automatic_updates', [$domain, 'plugin', 0], 'wpgpl_vault')) {
                as_schedule_recurring_action(
                    time() + DAY_IN_SECONDS,
                    DAY_IN_SECONDS,
                    'wpgpl_vault_multisite_automatic_updates',
                    [$domain, 'plugin', 0],
                    'wpgpl_vault'
                );
                error_log("Ação automática de multisites agendada para o domínio $domain.");
            }
        } else {
            // Se o backup estiver ativo ou ambos os auto updates desativados, desagende a ação para esse domínio
            $timestamp = as_next_scheduled_action('wpgpl_vault_multisite_automatic_updates', [$domain, 'plugin', 0], 'wpgpl_vault');
            if ($timestamp) {
                as_unschedule_action('wpgpl_vault_multisite_automatic_updates', [$domain, 'plugin', 0], 'wpgpl_vault');
                error_log("Ação automática desagendada para o domínio $domain porque o backup está ativo ou ambos auto updates estão desativados.");
            }
        }
    }

    // Se todos os domínios atenderem às condições para desagendar
    if ($all_desagendado) {
        error_log('Todos os domínios têm auto updates desativados ou backup ativo. Desagendando todas as ações automáticas.');

        // Desagenda todas as ações
        $scheduled_actions = as_get_scheduled_actions([
            'hook' => 'wpgpl_vault_multisite_automatic_updates',
            'status' => ActionScheduler_Store::STATUS_PENDING,
        ]);

        foreach ($scheduled_actions as $action) {
            as_unschedule_action('wpgpl_vault_multisite_automatic_updates', $action->get_args(), 'wpgpl_vault');
        }
    }
}
register_activation_hook(WPGPL_PLUGIN_PATH . 'wpgpl-vault.php', 'wpgpl_vault_schedule_multisite_updates');
add_action('wpgpl_check_multisite_automatic_update', 'wpgpl_vault_schedule_multisite_updates');

function wpgpl_vault_schedule_check_updates() {
    // Verifica se a classe ActionScheduler está disponível
    if (class_exists('ActionScheduler')) {
        // Verifica se a ação já está agendada para evitar duplicações
        if (!as_next_scheduled_action('wpgpl_vault_check_updates', [], 'wpgpl_vault')) {
            // Agenda a ação para rodar a cada 6 horas usando ActionScheduler
            as_schedule_recurring_action(time() + 6 * HOUR_IN_SECONDS, 6 * HOUR_IN_SECONDS, 'wpgpl_vault_check_updates', [], 'wpgpl_vault');
            error_log('Ação de verificação de atualizações agendada para cada 6 horas com sucesso');
        }
    } else {
        error_log('ActionScheduler não está disponível para agendar wpgpl_vault_check_updates');
    }
}
register_activation_hook(WPGPL_PLUGIN_PATH . 'wpgpl-vault.php', 'wpgpl_vault_schedule_check_updates');

function wpgpl_vault_unschedule_updates() {

    // Desagendar a ação principal de atualizações automáticas
    $timestamp = as_next_scheduled_action('wpgpl_vault_automatic_updates', [], 'wpgpl_vault');
    if ($timestamp) {
        as_unschedule_action('wpgpl_vault_automatic_updates', [], 'wpgpl_vault');
        error_log('Ação automática wpgpl_vault_automatic_updates desagendada.');
    }

    // Desagendar todas as ações agendadas com parâmetros específicos para domínios
    $scheduled_domain_actions = as_get_scheduled_actions([
        'hook' => 'wpgpl_vault_multisite_automatic_updates',
        'status' => ActionScheduler_Store::STATUS_PENDING,
    ]);

    foreach ($scheduled_domain_actions as $action) {
        as_unschedule_action('wpgpl_vault_multisite_automatic_updates', $action->get_args(), 'wpgpl_vault');
        error_log('Ação wpgpl_vault_multisite_automatic_updates desagendada para o domínio: ' . json_encode($action->get_args()));
    }

    // Desagendar qualquer outra ação de 'wpgpl_vault_automatic_updates' com argumentos variados
    $all_scheduled_actions = as_get_scheduled_actions([
        'hook' => 'wpgpl_vault_automatic_updates',
        'status' => ActionScheduler_Store::STATUS_PENDING,
    ]);

    foreach ($all_scheduled_actions as $action) {
        as_unschedule_action('wpgpl_vault_automatic_updates', $action->get_args(), 'wpgpl_vault');
        error_log('Ação adicional wpgpl_vault_automatic_updates desagendada para argumentos: ' . json_encode($action->get_args()));
    }

    // Desagendar a ação de verificação de atualizações 'wpgpl_vault_check_updates'
    $check_updates_timestamp = as_next_scheduled_action('wpgpl_vault_check_updates', [], 'wpgpl_vault');
    if ($check_updates_timestamp) {
        as_unschedule_action('wpgpl_vault_check_updates', [], 'wpgpl_vault');
        error_log('Ação de verificação de atualizações wpgpl_vault_check_updates desagendada.');
    }
}
register_deactivation_hook(WPGPL_PLUGIN_PATH . 'wpgpl-vault.php', 'wpgpl_vault_unschedule_updates');

function wpgpl_deactivate() {
    remove_action('deactivated_plugin', 'wpgpl_remove_plugin_from_archived_items');
}
register_deactivation_hook(WPGPL_PLUGIN_PATH, 'wpgpl_deactivate');

function wpgpl_enqueue_plugin_dark_styles($hook) {
    global $GLOBALS;
    $plugin_slug = $GLOBALS['wpgpl_plugin_slug'];

    // Verifica se estamos na página principal do plugin
    if ($hook === 'toplevel_page_' . $plugin_slug) {
        // Enfileirar estilo para a página de administração com tema escuro
        wp_enqueue_style(
            'dark-admin-page-style',
            WPGPL_PLUGIN_URL . 'assets/css/dark/dark-admin-page-min.css',
            array(),
            time(), // Ou substitua por um número de versão se necessário
            'all'
        );
    }

    // Verifica se estamos na página de ativação
    if ($hook === $plugin_slug . '_page_' . $plugin_slug . '-activation' || $hook === 'admin_page_' . $plugin_slug . '-activation') {
        // Enfileirar estilo para a página de ativação com tema escuro
        wp_enqueue_style(
            'dark-activation-page-style',
            WPGPL_PLUGIN_URL . 'assets/css/dark/dark-activation-page-min.css',
            array(),
            time(), // Ou substitua por um número de versão se necessário
            'all'
        );
    }
    
    // Verifica se estamos na página de histórico
    if ($hook === $plugin_slug . '_page_' . $plugin_slug . '-history' || $hook === 'admin_page_' . $plugin_slug . '-history') {
        // Enfileirar estilo para a página de histórico com tema escuro
        wp_enqueue_style(
            'dark-history-page-style',
            WPGPL_PLUGIN_URL . 'assets/css/dark/dark-history-page-min.css',
            array(),
            time(), // Ou substitua por um número de versão se necessário
            'all'
        );
    }
    
    if ($hook === $plugin_slug . '_page_' . $plugin_slug . '-backup' || $hook === 'admin_page_' . $plugin_slug . '-backup') {
        // Enfileirar estilo para a página de backup com tema escuro
        wp_enqueue_style(
            'dark-history-page-style',
            WPGPL_PLUGIN_URL . 'assets/css/dark/dark-backup-page-min.css',
            array(),
            time(), // Ou substitua por um número de versão se necessário
            'all'
        );
    }
    
    if ($hook === $plugin_slug . '_page_' . $plugin_slug . '-multisites' || $hook === 'admin_page_' . $plugin_slug . '-multisites') {
        // Enfileirar estilo para a página de multisites com tema escuro
        wp_enqueue_style(
            'dark-multisites-page-style',
            WPGPL_PLUGIN_URL . 'assets/css/dark/dark-multisites-page-min.css',
            array(),
            time(), // Ou substitua por um número de versão se necessário
            'all'
        );
    }
    
    if ($hook === $plugin_slug . '_page_' . $plugin_slug . '-domain' || $hook === 'admin_page_' . $plugin_slug . '-domain') {
        // Enfileirar estilo para a página de domain com tema escuro
        wp_enqueue_style(
            'dark-domain-page-style',
            WPGPL_PLUGIN_URL . 'assets/css/dark/dark-admin-by-domain-page-min.css',
            array(),
            time(), // Ou substitua por um número de versão se necessário
            'all'
        );
    }
}

// Função para enfileirar estilos
function wpgpl_enqueue_plugin_light_styles($hook) {
    global $GLOBALS;
    $plugin_slug = $GLOBALS['wpgpl_plugin_slug'];

    if ($hook === 'toplevel_page_' . $plugin_slug) {
        // Enfileirar estilo para a página de administração
        wp_enqueue_style(
            'admin-page-style',
            WPGPL_PLUGIN_URL . 'assets/css/light/light-admin-page-min.css',
            array(),
            time(), // Ou substitua por um número de versão se necessário
            'all'
        );
    }

    if ($hook === $plugin_slug . '_page_' . $plugin_slug . '-activation' || $hook === 'admin_page_' . $plugin_slug . '-activation') {
        // Enfileirar estilo para a página de ativação
        wp_enqueue_style(
            'activation-page-style',
            WPGPL_PLUGIN_URL . 'assets/css/light/light-activation-page-min.css',
            array(),
            time(), // Ou substitua por um número de versão se necessário
            'all'
        );
    }
    
    if ($hook === $plugin_slug . '_page_' . $plugin_slug . '-history' || $hook === 'admin_page_' . $plugin_slug . '-history') {
        // Enfileirar estilo para a página de histórico
        wp_enqueue_style(
            'history-page-style',
            WPGPL_PLUGIN_URL . 'assets/css/light/light-history-page-min.css',
            array(),
            time(), // Ou substitua por um número de versão se necessário
            'all'
        );
    }
    
    if ($hook === $plugin_slug . '_page_' . $plugin_slug . '-backup' || $hook === 'admin_page_' . $plugin_slug . '-backup') {
        // Enfileirar estilo para a página de backup
        wp_enqueue_style(
            'history-page-style',
            WPGPL_PLUGIN_URL . 'assets/css/light/light-backup-page-min.css',
            array(),
            time(), // Ou substitua por um número de versão se necessário
            'all'
        );
    }
    
    if ($hook === $plugin_slug . '_page_' . $plugin_slug . '-multisites' || $hook === 'admin_page_' . $plugin_slug . '-multisites') {
        // Enfileirar estilo para a página de multisites
        wp_enqueue_style(
            'multisites-page-style',
            WPGPL_PLUGIN_URL . 'assets/css/light/light-multisites-page-min.css',
            array(),
            time(), // Ou substitua por um número de versão se necessário
            'all'
        );
    }
    
    if ($hook === $plugin_slug . '_page_' . $plugin_slug . '-domain' || $hook === 'admin_page_' . $plugin_slug . '-domain') {
        // Enfileirar estilo para a página de multisites
        wp_enqueue_style(
            'domain-page-style',
            WPGPL_PLUGIN_URL . 'assets/css/light/light-admin-by-domain-page-min.css',
            array(),
            time(), // Ou substitua por um número de versão se necessário
            'all'
        );
    }
}

function wpgpl_vault_enqueue_scripts($hook) {
    global $GLOBALS;
    $plugin_slug = $GLOBALS['wpgpl_plugin_slug'];

    // Scripts a serem enfileirados
    $scripts = array();

    if ($hook === $plugin_slug . '_page_' . $plugin_slug . '-activation' || $hook === 'admin_page_' . $plugin_slug . '-activation') {
        wp_enqueue_script('wpgpl-vault-license-activation', WPGPL_PLUGIN_URL . 'assets/js/license-activation-min.js', array('jquery'), time(), true);
        wp_enqueue_script('wpgpl-vault-get-ip', WPGPL_PLUGIN_URL . 'assets/js/get-ip-min.js', array('jquery'), time(), true);
        $scripts[] = 'wpgpl-vault-theme';
        wp_enqueue_script('wpgpl-vault-theme', WPGPL_PLUGIN_URL . 'assets/js/activation-theme-change-min.js', array('jquery'), time(), true);
        wp_enqueue_script('wpgpl-vault-offcanvas', WPGPL_PLUGIN_URL . 'assets/js/offcanvas-min.js', array('jquery'), time(), true);
    }

    if ($hook === $plugin_slug . '_page_' . $plugin_slug . '-history' || $hook === 'admin_page_' . $plugin_slug . '-history') {
        wp_enqueue_script('wpgpl-vault-offcanvas', WPGPL_PLUGIN_URL . 'assets/js/offcanvas-min.js', array('jquery'), time(), true);
        $scripts[] = 'wpgpl-vault-theme';
        wp_enqueue_script('wpgpl-vault-theme', WPGPL_PLUGIN_URL . 'assets/js/history-theme-change-min.js', array('jquery'), time(), true);
        wp_enqueue_script('wpgpl-vault-history-pagination', WPGPL_PLUGIN_URL . 'assets/js/history-pagination-min.js', array('jquery'), time(), true);
    }

    if ($hook === $plugin_slug . '_page_' . $plugin_slug . '-backup' || $hook === 'admin_page_' . $plugin_slug . '-backup') {
        wp_enqueue_script('wpgpl-vault-offcanvas', WPGPL_PLUGIN_URL . 'assets/js/offcanvas-min.js', array('jquery'), time(), true);
        $scripts[] = 'wpgpl-vault-theme';
        wp_enqueue_script('wpgpl-vault-theme', WPGPL_PLUGIN_URL . 'assets/js/backup-theme-change-min.js', array('jquery'), time(), true);
        wp_enqueue_script('wpgpl-vault-backup-page', WPGPL_PLUGIN_URL . 'assets/js/backup-page-min.js', array('jquery'), time(), true);
    }

    if ($hook === $plugin_slug . '_page_' . $plugin_slug . '-multisites' || $hook === 'admin_page_' . $plugin_slug . '-multisites') {
        wp_enqueue_script('wpgpl-vault-offcanvas', WPGPL_PLUGIN_URL . 'assets/js/offcanvas-min.js', array('jquery'), time(), true);
        $scripts[] = 'wpgpl-vault-theme';
        wp_enqueue_script('wpgpl-vault-theme', WPGPL_PLUGIN_URL . 'assets/js/multisites-theme-change-min.js', array('jquery'), time(), true);
        wp_enqueue_script('wpgpl-vault-multisites', WPGPL_PLUGIN_URL . 'assets/js/add-site-min.js', array('jquery'), time(), true);
        wp_enqueue_script('wpgpl-vault-disconnect-domain', WPGPL_PLUGIN_URL . 'assets/js/disconnect-domain-min.js', array('jquery'), time(), true);
    }

    if ($hook === $plugin_slug . '_page_' . $plugin_slug . '-domain' || $hook === 'admin_page_' . $plugin_slug . '-domain') {
        wp_enqueue_script('wpgpl-vault-admin-page', WPGPL_PLUGIN_URL . 'assets/js/admin-by-domain-page-min.js', array('jquery'), time(), true);
        wp_enqueue_script('wpgpl-vault-support-button', WPGPL_PLUGIN_URL . 'assets/js/support-button-min.js', array('jquery'), time(), true);
        $scripts[] = 'wpgpl-vault-theme';
        wp_enqueue_script('wpgpl-vault-theme', WPGPL_PLUGIN_URL . 'assets/js/admin-by-domain-theme-change-min.js', array('jquery'), time(), true);
        wp_enqueue_script('wpgpl-vault-archived', WPGPL_PLUGIN_URL . 'assets/js/archived-by-domain-min.js', array('jquery'), time(), true);
        wp_enqueue_script('wpgpl-vault-offcanvas', WPGPL_PLUGIN_URL . 'assets/js/offcanvas-min.js', array('jquery'), time(), true);
        wp_enqueue_script('wpgpl-vault-time-cron', WPGPL_PLUGIN_URL . 'assets/js/time-cron-min.js', array('jquery'), time(), true);
    }

    if ($hook === 'toplevel_page_' . $plugin_slug) {
        wp_enqueue_script('wpgpl-vault-admin-page', WPGPL_PLUGIN_URL . 'assets/js/admin-page-min.js', array('jquery'), time(), true);
        wp_enqueue_script('wpgpl-vault-support-button', WPGPL_PLUGIN_URL . 'assets/js/support-button-min.js', array('jquery'), time(), true);
        $scripts[] = 'wpgpl-vault-theme';
        wp_enqueue_script('wpgpl-vault-theme', WPGPL_PLUGIN_URL . 'assets/js/admin-theme-change-min.js', array('jquery'), time(), true);
        wp_enqueue_script('wpgpl-vault-archived', WPGPL_PLUGIN_URL . 'assets/js/archived-min.js', array('jquery'), time(), true);
        wp_enqueue_script('wpgpl-vault-offcanvas', WPGPL_PLUGIN_URL . 'assets/js/offcanvas-min.js', array('jquery'), time(), true);
        wp_enqueue_script('wpgpl-vault-time-cron', WPGPL_PLUGIN_URL . 'assets/js/time-cron-min.js', array('jquery'), time(), true);
    }

    // Localizar a URL do plugin para todos os scripts que contêm "theme-change"
    foreach ($scripts as $script) {
        wp_localize_script($script, 'wpgplPluginData', array(
            'pluginUrl' => WPGPL_PLUGIN_URL
        ));
    }
}
add_action('admin_enqueue_scripts', 'wpgpl_vault_enqueue_scripts');

function wpgpl_vault_plugins_page($plugins) {
    $key = WPGPL_PLUGIN_BASENAME;

    $plugin_name = wpgpl_get_white_label_option('wpgpl_plugin_name', 'WPGPL Vault');
    $plugin_description = wpgpl_get_white_label_option('wpgpl_plugin_description', 'Proteja e gerencie seu site WordPress com o WPGPL Vault. Faça backups automáticos, verifique arquivos com relatórios do VirusTotal, instale atualizações manualmente, tenha controle total com rollback e histórico de mudanças.');
    $agency_name = wpgpl_get_white_label_option('wpgpl_agency_name', 'Ian Chamba');
    $agency_url = wpgpl_get_white_label_option('wpgpl_agency_url', 'https://wpgpl.com.br/');

    $plugins[$key]['Name'] = $plugin_name;
    $plugins[$key]['Description'] = $plugin_description;
    $plugins[$key]['Author'] = $agency_name;
    $plugins[$key]['AuthorName'] = $agency_name;
    $plugins[$key]['AuthorURI'] = $agency_url;
    $plugins[$key]['PluginURI'] = $agency_url;

    // Caminho do plugin Action Scheduler
    $action_scheduler_plugin = 'action-scheduler/action-scheduler.php';

    // Verifica se a variável global está definida e se é diferente de 'WPGPL Vault'
    if (isset($GLOBALS['wpgpl_plugin_name']) && $GLOBALS['wpgpl_plugin_name'] !== 'WPGPL Vault') {
        // Verifica se o Action Scheduler está na lista de plugins
        if (isset($plugins[$action_scheduler_plugin])) {
            unset($plugins[$action_scheduler_plugin]); // Remove da lista
        }
    }

    return $plugins;
}
add_filter('all_plugins', 'wpgpl_vault_plugins_page');

global $wpgpl_theme_color;

$wpgpl_theme_color = wpgpl_vault_get_option('wpgpl_theme_color');

if (empty($wpgpl_theme_color) || $wpgpl_theme_color == 0) {
    add_action('admin_enqueue_scripts', 'wpgpl_enqueue_plugin_dark_styles');
} elseif ($wpgpl_theme_color == 1) {
    add_action('admin_enqueue_scripts', 'wpgpl_enqueue_plugin_light_styles');
}

function wpgpl_set_global_theme_variables() {

    global $wpgpl_theme_color;
    
    $wpgpl_theme_color = wpgpl_vault_get_option('wpgpl_theme_color');
    
    if ($wpgpl_theme_color === '1') {
        $GLOBALS['wpgpl_plugin_slogan_url'] = wpgpl_get_white_label_option(
            'wpgpl_plugin_slogan_dark_url',
            WPGPL_PLUGIN_URL . 'media/dark_slogan.svg'
        );
    } else {
        $GLOBALS['wpgpl_plugin_slogan_url'] = wpgpl_get_white_label_option(
            'wpgpl_plugin_slogan_light_url',
            WPGPL_PLUGIN_URL . 'media/light_slogan.svg'
        );
    }
}

$whitelabel_icon = WPGPL_PLUGIN_PATH . 'media/icon_whitelabel.svg';
$default_icon = WPGPL_PLUGIN_URL . 'media/icon_wpgpl.svg';

if (file_exists($whitelabel_icon)) {
    $GLOBALS['wpgpl_plugin_icon_url'] = WPGPL_PLUGIN_URL . 'media/icon_whitelabel.svg';
} else {
    $GLOBALS['wpgpl_plugin_icon_url'] = $default_icon;
}

$GLOBALS['wpgpl_plugin_name'] = wpgpl_get_white_label_option('wpgpl_plugin_name', 'WPGPL Vault');
$GLOBALS['wpgpl_plugin_slug'] = sanitize_title($GLOBALS['wpgpl_plugin_name']);
$GLOBALS['wpgpl_license_key'] = wpgpl_vault_get_option('wpgpl_vault_license_key', '');
$GLOBALS['wpgpl_uuid'] = wpgpl_vault_get_option('wpgpl_vault_uuid', '');
$GLOBALS['wpgpl_backup_integration'] = wpgpl_vault_get_option('wpgpl_vault_backup_integration', 0);

if ($GLOBALS['wpgpl_backup_integration'] == 0) {
        remove_action('duplicator_pro_build_completed', 'wpgpl_vault_automatic_updates');
        remove_action('ai1wm_status_export_done', 'wpgpl_vault_automatic_updates');
        remove_action('updraft_final_backup_history', 'wpgpl_vault_automatic_updates');
}